options(echo=TRUE) # Enable output in Rscript for debugging
library("dada2")
library("phyloseq")
library("magrittr")

#sequences were multiplexed on one PCR, so 16S and ITS had the same barcodes and needed to be seperated before further analysis 

print("This script is current set to process fasta sequences in the directory it resides.")
path <- getwd()
print(paste("Executing 16S and ITS splitting script in:", path))

fnFs <- sort(list.files(path, pattern="_R1_001.fastq.gz", full.names = TRUE))
fnRs <- sort(list.files(path, pattern="_R2_001.fastq.gz", full.names = TRUE))

print("Cutadapt preprocessing to filter out 16S sequences only")
dir.create(file.path("16S"), showWarnings = TRUE)

#Cutadapt is set not to trim sequences, and to place everything with the 16S primer in the 16S subdirectory, and everything else (ie ITS) in the ITS subdirectory.

for(i in 1:length(fnFs)){
system2("cutadapt",paste0("-g CCTACGGGNGGCWGCAG -G GACTACHVGGGTATCTAATCC --no-trim --discard-untrimmed -o 16S/", basename(fnFs[i]), " -p 16S/", basename(fnRs[i]), " ", fnFs[i], " ", fnRs[i])) 
}

  print("Cutadapt preprocessing to filter out ITS sequences only")
  dir.create(file.path("ITS"), showWarnings = TRUE)
  
  
  for(i in 1:length(fnFs)){
    system2("cutadapt",paste0("-g CCTACGGGNGGCWGCAG -G GACTACHVGGGTATCTAATCC --no-trim --discard-trimmed -o ITS/", basename(fnFs[i]), " -p ITS/", basename(fnRs[i]), " ", fnFs[i], " ", fnRs[i])) 
  }
  
  print("Completed preprocessing!")

