options(echo=TRUE) # Enable output in Rscript for debugging
library("phyloseq")

#Update working directory to be where USEARCH outputs are stored
setwd("~/Desktop/Parks16S/USEARCH")

#Import USEARCH taxonomy to R (RDP)
library("RDPutils")
  USEARCHphy.table.RDP <-import_sintax_file("sintaxR.txt", confidence = 0.8) #Update to location of sintax file from USEARCH - imported fine, 8009 taxa!!
  
#Import USEARCH taxonomy to R (SILVA)
library("RDPutils")
USEARCHphy.table.SILVA <-import_sintax_file("sintaxS.txt", confidence = 0.8) #Stopped at 1985 - prob need to manually adjust the 

#Import OTU table to R
USEARCHOTU.table <- read.csv("zotutab_raw.csv", header = TRUE, sep=",", row.names = 1) #Update to location of OTU file from USEARCH - not getting data for some reason but CSV file looks fine. Wil have o come back to this.

#Make into phyloseq 1 w RDP taxonomy.

OTU = otu_table(USEARCHOTU.table, taxa_are_rows = TRUE) 
TAX = tax_table(USEARCHphy.table)

#combine above into phyloseq object

ps = phyloseq(OTU, USEARCHphy.table)

#bring metadata into R

metadata <- read.csv("~/Documents/PhD sample data/ParksMetadata16S.csv", sep=",", header=TRUE, row.names = 1) #Update to where metadata file is stored in csv

#bring metadata into phyloseq object

ps <- merge_phyloseq(ps, sample_data(metadata))

#If desired
#load fasta file with the DNA sequences for each USEARCH ZOTU into phyloseq (so can compare between pipelines) 
#Create DNA string object
library(Biostrings)
reference_seqs <- readDNAStringSet(file = "zotus.fa",
                                   format = "fasta", nrec = -1L, skip = 0L, seek.first.rec = FALSE, use.names = TRUE) #update to where USEARCH ZOTUS file is stored.
rs <- reference_seqs
SEQ <- refseq(rs)

#Combine in to phyloseq
SAM <- sample_data(metadata)
ps <- phyloseq(OTU,SEQ,TAX,SAM)

#view refseq and put it into a data frame for easier export/manipulation

refseq(ps)
seqsummary <- as.data.frame(refseq(ps)) #makes a data frame with the asv names and the corresponding sequences

#code to make this in to an OTU table which looks consistant to Dada2 if desireed, for ease of comparison

#Paste OTU table and seq summary together in R by ASV
library(dplyr)
OTU.table <- as.data.frame(otu_table(ps)) #Make this a data frame too

#Put ZOTUs in the first column so it can be accessed by join commmand below

library(tibble)
OTU.table <- rownames_to_column(OTU.table, "ASV")
seqsummary <- rownames_to_column(seqsummary, "ASV")

#Join files by ASV

OTUwseq <- left_join(seqsummary, OTU.table, by = "ASV")

#delete ASV nos and replace with the DNA seq

row.names(OTUwseq) <- OTUwseq$x

#delete ASV and X cols so it matches the OTU Dada2 outputs

OTUwseq <- OTUwseq[-c(1,2)]

#This can then be exported in to a CSV file or into phyloseq for further work

write.csv(OTUwseq, "OTUwseqFinalUSEARCH16SParks1405.csv", row.name = TRUE) 

#save workspace

save.image("~/Desktop/Parks16S/USEARCH/16SParksUSEARCHintopsfinal1405.RData")
