#load packages
library("phyloseq")
library(ggplot2)

#Set working directory
setwd("~/Desktop/Parks16S/USEARCHSILVA")

#load file

load("/home/katie/Desktop/Parks16S/USEARCHSILVA/Parks16SUSEARCHSILVA.Rda")

#prune out controls - not used for BPS stats
ps.s = subset_samples(ps, All.controls == "Sample") 

#look at taxonomy

#genera ID by pipeline

tax <- as.data.frame(tax_table(ps.s))
no.genus <- length(unique(tax$Genus)) #694

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV

genussummary <- tax_glom(ps.s, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV

#alpha diversity
library(ggplot2)

pAlphaG = plot_richness(genussummary,
                        shape = "Control.type",
                        color = "Location",
                        measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                        title = "Alpha Diveristy")
pAlphaG + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt = data.table(pAlphaG$data)

#subset to just observed
alphadtO <- alphadt[(variable == "Observed")]
# Calc mean observed
meanobserved <- mean(alphadtO$value) #127
# Subset to just the Chao1 index
alphadtC <- alphadt[(variable == "Chao1")]
# Calc mean Chao1
meanChao1 <- mean(alphadtC$value) #141
#subset to just Shannon
alphadtS <- alphadt[(variable == "Shannon")]
# Calc mean Shannon
meanshannon <- mean(alphadtS$value) #2.53
#Calc exp of Shannon (Hill no D1)
expshannon <- exp(meanshannon) #12.56
#subset to just inv simpson
alphadtI <- alphadt[(variable == "InvSimpson")]
library(dplyr)
alphadtI2 <- filter(alphadtI, value!= "Inf")#Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp <- mean(alphadtI2$value) #8.98


#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG <- t(otu_table(genussummary))
betadiversityG <- vegdist(OTU.tableG, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata <- as.matrix(betadiversityG) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata) #69
betadiversityGdata<-t(matrix(t(betadiversityGdata)[which(!is.na(betadiversityGdata))],nrow=69,ncol=68)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG <- mean(betadiversityGdata) #0.80

#Median of distances
medianbetadiversityG <- median(betadiversityGdata) #0.83

#range of distances
rangebetadiversityG <- range(betadiversityGdata) #0.0886 - 1

#standard deviation of distances

sdbetadiversityG <- sd(betadiversityGdata) #0.18

#no ASVs with no genus assigned

ASVnogenus <- tax$Genus[grep("uncl", tax$Genus)] #subset ASVs with uncl = unclassifed somewhere in Genus - no genus ID
no.ASVnogenus <- length(ASVnogenus) #1681

#% ASVs with no genus ID

PCASVnogenus <- 1681/4400

#Save workspace

save.image("~/Desktop/Parks16S/USEARCHSILVA/Parks16SUSEARCHSILVABPSnocontrols.RData")

#########################################################################################################################################################################
#Calculate breakdown of indicators by Park for mann-whitney U test to test statistical significant of differences in stats between pipelines

load("~/Desktop/Parks16S/USEARCHSILVA/Parks16SUSEARCHSILVABPSnocontrols.RData")

#filter samples by park, then run above on each park

ps.s.AS <- subset_samples(ps.s, Location == "Aotea Square ") #needs a space at the end
ps.s.CP <- subset_samples(ps.s, Location == "Cornwall Park") 
ps.s.FF <- subset_samples(ps.s, Location == "Fijoa Forest")
ps.s.KH <- subset_samples(ps.s, Location == "Keith Hay Park")
ps.s.MA <- subset_samples(ps.s, Location == "Mt Albert Park")
ps.s.ME <- subset_samples(ps.s, Location == "Mt Eden Domain")
ps.s.RL <- subset_samples(ps.s, Location == "Rural location")
ps.s.TM <- subset_samples(ps.s, Location == "The Museum")
ps.s.WF <- subset_samples(ps.s, Location == "Warren Freer Park")
ps.s.WS <- subset_samples(ps.s, Location == "Western Springs")
ps.s.WP <- subset_samples(ps.s, Location == "Windmill Park")

################################ Aotea Square ###################################################################################################################################
#prune empty taxa
ps.s.AS <- prune_taxa(taxa_sums(ps.s.AS) > 0, ps.s.AS)

#genera ID by pipeline
tax.AS <- as.data.frame(tax_table(ps.s.AS))
no.genus.AS <- length(unique(tax.AS$Genus)) #120 

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.AS <- tax_glom(ps.s.AS, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.AS = plot_richness(genussummary.AS,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.AS + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.AS = data.table(pAlphaG.AS$data)

#subset to just observed
alphadtO.AS <- alphadt.AS[(variable == "Observed")]
# Calc mean observed
meanobserved.AS <- mean(alphadtO.AS$value) #39.4
# Subset to just the Chao1 index
alphadtC.AS <- alphadt.AS[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.AS <- mean(alphadtC.AS$value) #43.98
#subset to just Shannon
alphadtS.AS <- alphadt.AS[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.AS <- mean(alphadtS.AS$value) #1.79
#Calc exp of Shannon (Hill no D1)
expshannon.AS <- exp(meanshannon.AS) #5.97
#subset to just inv simpson
alphadtI.AS <- alphadt.AS[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.AS <- filter(alphadtI.AS, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.AS <- mean(alphadtI2.AS$value) #4.06

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.AS <- t(otu_table(genussummary.AS))
betadiversityG.AS <- vegdist(OTU.tableG.AS, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.AS <- as.matrix(betadiversityG.AS) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.AS)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.AS) #5
betadiversityGdata.AS<-t(matrix(t(betadiversityGdata.AS)[which(!is.na(betadiversityGdata.AS))],nrow=5,ncol=4)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.AS <- mean(betadiversityGdata.AS) #0.84

#Median of distances  
medianbetadiversityG.AS <- median(betadiversityGdata.AS) #0.89

#range of distances
rangebetadiversityG.AS <- range(betadiversityGdata.AS) #0.421 - 1

#standard deviation of distances

sdbetadiversityG.AS <- sd(betadiversityGdata.AS) #0.18

ASVnogenus.AS <- tax.AS$Genus[grep("uncl", tax.AS$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.AS <- length(ASVnogenus.AS) #79

#% ASVs with no genus ID

PCASVnogenus.AS <- 79/252 #31% - 252 is from the total no of rows in the otu and tax table for ps.s.AS

################################Cornwall Park ####################################################################################################################################
#prune empty taxa
ps.s.CP <- prune_taxa(taxa_sums(ps.s.CP) > 0, ps.s.CP)

#genera ID by pipeline
tax.CP <- as.data.frame(tax_table(ps.s.CP))
no.genus.CP <- length(unique(tax.CP$Genus)) #423   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.CP <- tax_glom(ps.s.CP, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.CP = plot_richness(genussummary.CP,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.CP + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.CP = data.table(pAlphaG.CP$data)

#subset to just observed
alphadtO.CP <- alphadt.CP[(variable == "Observed")]
# Calc mean observed
meanobserved.CP <- mean(alphadtO.CP$value) #162.33
# Subset to just the Chao1 index
alphadtC.CP <- alphadt.CP[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.CP <- mean(alphadtC.CP$value) #172.98
#subset to just Shannon
alphadtS.CP <- alphadt.CP[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.CP <- mean(alphadtS.CP$value) #2.79
#Calc exp of Shannon (Hill no D1)
expshannon.CP <- exp(meanshannon.CP) #16.33
#subset to just inv simpson
alphadtI.CP <- alphadt.CP[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.CP <- filter(alphadtI.CP, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.CP <- mean(alphadtI2.CP$value) #10.91

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.CP <- t(otu_table(genussummary.CP))
betadiversityG.CP <- vegdist(OTU.tableG.CP, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.CP <- as.matrix(betadiversityG.CP) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.CP)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.CP) #6
betadiversityGdata.CP<-t(matrix(t(betadiversityGdata.CP)[which(!is.na(betadiversityGdata.CP))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.CP <- mean(betadiversityGdata.CP) #0.81

#Median of distances  
medianbetadiversityG.CP <- median(betadiversityGdata.CP) #0.79

#range of distances
rangebetadiversityG.CP <- range(betadiversityGdata.CP) #0.502 - 1

#standard deviation of distances

sdbetadiversityG.CP <- sd(betadiversityGdata.CP) #0.16

ASVnogenus.CP <- tax.CP$Genus[grep("uncl", tax.CP$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.CP <- length(ASVnogenus.CP) #756

#% ASVs with no genus ID

PCASVnogenus.CP <- 756/1931 #39% 

################################Fijoa Forest #####################################################################################################################################
#prune empty taxa
ps.s.FF <- prune_taxa(taxa_sums(ps.s.FF) > 0, ps.s.FF)

#genera ID by pipeline
tax.FF <- as.data.frame(tax_table(ps.s.FF))
no.genus.FF <- length(unique(tax.FF$Genus)) #316   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.FF <- tax_glom(ps.s.FF, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.FF = plot_richness(genussummary.FF,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.FF + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.FF = data.table(pAlphaG.FF$data)

#subset to just observed
alphadtO.FF <- alphadt.FF[(variable == "Observed")]
# Calc mean observed
meanobserved.FF <- mean(alphadtO.FF$value) #139.17
# Subset to just the Chao1 index
alphadtC.FF <- alphadt.FF[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.FF <- mean(alphadtC.FF$value) #149.18
#subset to just Shannon
alphadtS.FF <- alphadt.FF[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.FF <- mean(alphadtS.FF$value) #2.98
#Calc exp of Shannon (Hill no D1)
expshannon.FF <- exp(meanshannon.FF) #19.60
#subset to just inv simpson
alphadtI.FF <- alphadt.FF[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.FF <- filter(alphadtI.FF, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.FF <- mean(alphadtI2.FF$value) #13.22

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.FF <- t(otu_table(genussummary.FF))
betadiversityG.FF <- vegdist(OTU.tableG.FF, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.FF <- as.matrix(betadiversityG.FF) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.FF)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.FF) #6
betadiversityGdata.FF<-t(matrix(t(betadiversityGdata.FF)[which(!is.na(betadiversityGdata.FF))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.FF <- mean(betadiversityGdata.FF) #0.85

#Median of distances  
medianbetadiversityG.FF <- median(betadiversityGdata.FF) #0.80

#range of distances
rangebetadiversityG.FF <- range(betadiversityGdata.FF) #0.61 - 0.999

#standard deviation of distances

sdbetadiversityG.FF <- sd(betadiversityGdata.FF) #0.12

ASVnogenus.FF <- tax.FF$Genus[grep("uncl", tax.FF$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.FF <- length(ASVnogenus.FF) #557

#% ASVs with no genus ID

PCASVnogenus.FF <- 557/1519 #37% 

################################Keith Hay Park ###################################################################################################################################
#prune empty taxa
ps.s.KH <- prune_taxa(taxa_sums(ps.s.KH) > 0, ps.s.KH)

#genera ID by pipeline
tax.KH <- as.data.frame(tax_table(ps.s.KH))
no.genus.KH <- length(unique(tax.KH$Genus)) #341   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.KH <- tax_glom(ps.s.KH, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.KH = plot_richness(genussummary.KH,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.KH + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.KH = data.table(pAlphaG.KH$data)

#subset to just observed
alphadtO.KH <- alphadt.KH[(variable == "Observed")]
# Calc mean observed
meanobserved.KH <- mean(alphadtO.KH$value) #117.86
# Subset to just the Chao1 index
alphadtC.KH <- alphadt.KH[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.KH <- mean(alphadtC.KH$value) #134.08
#subset to just Shannon
alphadtS.KH <- alphadt.KH[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.KH <- mean(alphadtS.KH$value) #2.35
#Calc exp of Shannon (Hill no D1)
expshannon.KH <- exp(meanshannon.KH) #10.55
#subset to just inv simpson
alphadtI.KH <- alphadt.KH[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.KH <- filter(alphadtI.KH, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.KH <- mean(alphadtI2.KH$value) #6.20

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.KH <- t(otu_table(genussummary.KH))
betadiversityG.KH <- vegdist(OTU.tableG.KH, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.KH <- as.matrix(betadiversityG.KH) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.KH)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.KH) #7
betadiversityGdata.KH<-t(matrix(t(betadiversityGdata.KH)[which(!is.na(betadiversityGdata.KH))],nrow=7,ncol=6)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.KH <- mean(betadiversityGdata.KH) #0.78

#Median of distances  
medianbetadiversityG.KH <- median(betadiversityGdata.KH) #0.76

#range of distances
rangebetadiversityG.KH <- range(betadiversityGdata.KH) #0.368 - 0.996

#standard deviation of distances

sdbetadiversityG.KH <- sd(betadiversityGdata.KH) #0.21

ASVnogenus.KH <- tax.KH$Genus[grep("uncl", tax.KH$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.KH <- length(ASVnogenus.KH) #468

#% ASVs with no genus ID

PCASVnogenus.KH <- 468/1347 #35% 

################################Mt Albert Park ###################################################################################################################################
#prune empty taxa
ps.s.MA <- prune_taxa(taxa_sums(ps.s.MA) > 0, ps.s.MA)

#genera ID by pipeline
tax.MA <- as.data.frame(tax_table(ps.s.MA))
no.genus.MA <- length(unique(tax.MA$Genus)) #340   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.MA <- tax_glom(ps.s.MA, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.MA = plot_richness(genussummary.MA,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.MA + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.MA = data.table(pAlphaG.MA$data)

#subset to just observed
alphadtO.MA <- alphadt.MA[(variable == "Observed")]
# Calc mean observed
meanobserved.MA <- mean(alphadtO.MA$value) #122.29
# Subset to just the Chao1 index
alphadtC.MA <- alphadt.MA[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.MA <- mean(alphadtC.MA$value) #146.31
#subset to just Shannon
alphadtS.MA <- alphadt.MA[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.MA <- mean(alphadtS.MA$value) #2.46
#Calc exp of Shannon (Hill no D1)
expshannon.MA <- exp(meanshannon.MA) #11.66
#subset to just inv simpson
alphadtI.MA <- alphadt.MA[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.MA <- filter(alphadtI.MA, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.MA <- mean(alphadtI2.MA$value) #8.81

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.MA <- t(otu_table(genussummary.MA))
betadiversityG.MA <- vegdist(OTU.tableG.MA, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.MA <- as.matrix(betadiversityG.MA) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.MA)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.MA) #7
betadiversityGdata.MA<-t(matrix(t(betadiversityGdata.MA)[which(!is.na(betadiversityGdata.MA))],nrow=7,ncol=6)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.MA <- mean(betadiversityGdata.MA) #0.76

#Median of distances  
medianbetadiversityG.MA <- median(betadiversityGdata.MA) #0.83

#range of distances
rangebetadiversityG.MA <- range(betadiversityGdata.MA) #0.193 - 0.958

#standard deviation of distances

sdbetadiversityG.MA <- sd(betadiversityGdata.MA) #0.21

ASVnogenus.MA <- tax.MA$Genus[grep("uncl", tax.MA$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.MA <- length(ASVnogenus.MA) #514

#% ASVs with no genus ID

PCASVnogenus.MA <- 514/1334 #39% 

################################Mount Eden Domain ################################################################################################################################
#prune empty taxa
ps.s.ME <- prune_taxa(taxa_sums(ps.s.ME) > 0, ps.s.ME)

#genera ID by pipeline
tax.ME <- as.data.frame(tax_table(ps.s.ME))
no.genus.ME <- length(unique(tax.ME$Genus)) #385   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.ME <- tax_glom(ps.s.ME, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.ME = plot_richness(genussummary.ME,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.ME + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.ME = data.table(pAlphaG.ME$data)

#subset to just observed
alphadtO.ME <- alphadt.ME[(variable == "Observed")]
# Calc mean observed
meanobserved.ME <- mean(alphadtO.ME$value) #151
# Subset to just the Chao1 index
alphadtC.ME <- alphadt.ME[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.ME <- mean(alphadtC.ME$value) #164.94
#subset to just Shannon
alphadtS.ME <- alphadt.ME[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.ME <- mean(alphadtS.ME$value) #3.04
#Calc exp of Shannon (Hill no D1)
expshannon.ME <- exp(meanshannon.ME) #20.88
#subset to just inv simpson
alphadtI.ME <- alphadt.ME[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.ME <- filter(alphadtI.ME, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.ME <- mean(alphadtI2.ME$value) #10.94

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.ME <- t(otu_table(genussummary.ME))
betadiversityG.ME <- vegdist(OTU.tableG.ME, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.ME <- as.matrix(betadiversityG.ME) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.ME)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.ME) #6
betadiversityGdata.ME<-t(matrix(t(betadiversityGdata.ME)[which(!is.na(betadiversityGdata.ME))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.ME <- mean(betadiversityGdata.ME) #0.76

#Median of distances  
medianbetadiversityG.ME <- median(betadiversityGdata.ME) #0.79

#range of distances
rangebetadiversityG.ME <- range(betadiversityGdata.ME) #0.31 - 0.921

#standard deviation of distances

sdbetadiversityG.ME <- sd(betadiversityGdata.ME) #0.14

ASVnogenus.ME <- tax.CP$Genus[grep("uncl", tax.ME$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.ME <- length(ASVnogenus.ME) #475

#% ASVs with no genus ID

PCASVnogenus.ME <- 475/1470 #32% 

################################Rural location ###################################################################################################################################
#prune empty taxa
ps.s.RL <- prune_taxa(taxa_sums(ps.s.RL) > 0, ps.s.RL)

#genera ID by pipeline
tax.RL <- as.data.frame(tax_table(ps.s.RL))
no.genus.RL <- length(unique(tax.RL$Genus)) #326  

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.RL <- tax_glom(ps.s.RL, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.RL = plot_richness(genussummary.RL,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.RL + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.RL = data.table(pAlphaG.RL$data)

#subset to just observed
alphadtO.RL <- alphadt.RL[(variable == "Observed")]
# Calc mean observed
meanobserved.RL <- mean(alphadtO.RL$value) #102.83
# Subset to just the Chao1 index
alphadtC.RL <- alphadt.RL[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.RL <- mean(alphadtC.RL$value) #112.03
#subset to just Shannon
alphadtS.RL <- alphadt.RL[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.RL <- mean(alphadtS.RL$value) #2.06
#Calc exp of Shannon (Hill no D1)
expshannon.RL <- exp(meanshannon.RL) #7.84
#subset to just inv simpson
alphadtI.RL <- alphadt.RL[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.RL <- filter(alphadtI.RL, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.RL <- mean(alphadtI2.RL$value) #5.44

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.RL <- t(otu_table(genussummary.RL))
betadiversityG.RL <- vegdist(OTU.tableG.RL, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.RL <- as.matrix(betadiversityG.RL) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.RL)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.RL) #6
betadiversityGdata.RL<-t(matrix(t(betadiversityGdata.RL)[which(!is.na(betadiversityGdata.RL))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.RL <- mean(betadiversityGdata.RL) #0.88

#Median of distances  
medianbetadiversityG.RL <- median(betadiversityGdata.RL) #0.89

#range of distances
rangebetadiversityG.RL <- range(betadiversityGdata.RL) #0.394 - 1

#standard deviation of distances

sdbetadiversityG.RL <- sd(betadiversityGdata.RL) #0.15

ASVnogenus.RL <- tax.CP$Genus[grep("uncl", tax.RL$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.RL <- length(ASVnogenus.RL) #381

#% ASVs with no genus ID

PCASVnogenus.RL <- 381/1102 #35% 

################################The Museum #####################################################################################################################################
#prune empty taxa
ps.s.TM <- prune_taxa(taxa_sums(ps.s.TM) > 0, ps.s.TM)

#genera ID by pipeline
tax.TM <- as.data.frame(tax_table(ps.s.TM))
no.genus.TM <- length(unique(tax.TM$Genus)) #345  

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.TM <- tax_glom(ps.s.TM, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.TM = plot_richness(genussummary.TM,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.TM + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.TM = data.table(pAlphaG.TM$data)

#subset to just observed
alphadtO.TM <- alphadt.TM[(variable == "Observed")]
# Calc mean observed
meanobserved.TM <- mean(alphadtO.TM$value) #95.83
# Subset to just the Chao1 index
alphadtC.TM <- alphadt.TM[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.TM <- mean(alphadtC.TM$value) #117.46
#subset to just Shannon
alphadtS.TM <- alphadt.TM[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.TM <- mean(alphadtS.TM$value) #1.95
#Calc exp of Shannon (Hill no D1)
expshannon.TM <- exp(meanshannon.TM) #7.02
#subset to just inv simpson
alphadtI.TM <- alphadt.TM[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.TM <- filter(alphadtI.TM, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.TM <- mean(alphadtI2.TM$value) #6.89

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.TM <- t(otu_table(genussummary.TM))
betadiversityG.TM <- vegdist(OTU.tableG.TM, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.TM <- as.matrix(betadiversityG.TM) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.TM)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.TM) #6
betadiversityGdata.TM<-t(matrix(t(betadiversityGdata.TM)[which(!is.na(betadiversityGdata.TM))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.TM <- mean(betadiversityGdata.TM) #0.94

#Median of distances  
medianbetadiversityG.TM <- median(betadiversityGdata.TM) #0.99

#range of distances
rangebetadiversityG.TM <- range(betadiversityGdata.TM) #0.552 - 1

#standard deviation of distances

sdbetadiversityG.TM <- sd(betadiversityGdata.TM) #0.13

ASVnogenus.TM <- tax.TM$Genus[grep("uncl", tax.TM$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.TM <- length(ASVnogenus.TM) #370

#% ASVs with no genus ID

PCASVnogenus.TM <- 370/1262 #29% 

################################Warren Freer Park ################################################################################################################################
#prune empty taxa
ps.s.WF <- prune_taxa(taxa_sums(ps.s.WF) > 0, ps.s.WF)

#genera ID by pipeline
tax.WF <- as.data.frame(tax_table(ps.s.WF))
no.genus.WF <- length(unique(tax.WF$Genus)) #314  

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.WF <- tax_glom(ps.s.WF, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.WF = plot_richness(genussummary.WF,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.WF + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.WF = data.table(pAlphaG.WF$data)

#subset to just observed
alphadtO.WF <- alphadt.WF[(variable == "Observed")]
# Calc mean observed
meanobserved.WF <- mean(alphadtO.WF$value) #107.57
# Subset to just the Chao1 index
alphadtC.WF <- alphadt.WF[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.WF <- mean(alphadtC.WF$value) #121.22
#subset to just Shannon
alphadtS.WF <- alphadt.WF[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.WF <- mean(alphadtS.WF$value) #2.55
#Calc exp of Shannon (Hill no D1)
expshannon.WF <- exp(meanshannon.WF) #12.74
#subset to just inv simpson
alphadtI.WF <- alphadt.WF[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.WF <- filter(alphadtI.WF, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.WF <- mean(alphadtI2.WF$value) #7.27

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.WF <- t(otu_table(genussummary.WF))
betadiversityG.WF <- vegdist(OTU.tableG.WF, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.WF <- as.matrix(betadiversityG.WF) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.WF)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.WF) #7
betadiversityGdata.WF<-t(matrix(t(betadiversityGdata.WF)[which(!is.na(betadiversityGdata.WF))],nrow=7,ncol=6)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.WF <- mean(betadiversityGdata.WF) #0.66

#Median of distances  
medianbetadiversityG.WF <- median(betadiversityGdata.WF) #0.68

#range of distances
rangebetadiversityG.WF <- range(betadiversityGdata.WF) #0.367 - 0.882

#standard deviation of distances

sdbetadiversityG.WF <- sd(betadiversityGdata.WF) #0.16

ASVnogenus.WF <- tax.WF$Genus[grep("uncl", tax.WF$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.WF <- length(ASVnogenus.WF) #371

#% ASVs with no genus ID

PCASVnogenus.WF <- 371/1104 #34% 

################################Western Springs ##################################################################################################################################
#prune empty taxa
ps.s.WS <- prune_taxa(taxa_sums(ps.s.WS) > 0, ps.s.WS)

#genera ID by pipeline
tax.WS <- as.data.frame(tax_table(ps.s.WS))
no.genus.WS <- length(unique(tax.WS$Genus)) #450 

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.WS <- tax_glom(ps.s.WS, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.WS = plot_richness(genussummary.WS,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.WS + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.WS = data.table(pAlphaG.WS$data)

#subset to just observed
alphadtO.WS <- alphadt.WS[(variable == "Observed")]
# Calc mean observed
meanobserved.WS <- mean(alphadtO.WS$value) #192
# Subset to just the Chao1 index
alphadtC.WS <- alphadt.WS[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.WS <- mean(alphadtC.WS$value) #213.17
#subset to just Shannon
alphadtS.WS <- alphadt.WS[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.WS <- mean(alphadtS.WS$value) #3.00
#Calc exp of Shannon (Hill no D1)
expshannon.WS <- exp(meanshannon.WS) #20.18
#subset to just inv simpson
alphadtI.WS <- alphadt.WS[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.WS <- filter(alphadtI.WS, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.WS <- mean(alphadtI2.WS$value) #9,11

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.WS <- t(otu_table(genussummary.WS))
betadiversityG.WS <- vegdist(OTU.tableG.WS, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.WS <- as.matrix(betadiversityG.WS) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.WS)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.WS) #6
betadiversityGdata.WS<-t(matrix(t(betadiversityGdata.WS)[which(!is.na(betadiversityGdata.WS))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.WS <- mean(betadiversityGdata.WS) #0.68

#Median of distances  
medianbetadiversityG.WS <- median(betadiversityGdata.WS) #0.70

#range of distances
rangebetadiversityG.WS <- range(betadiversityGdata.WS) #0.353 - 0.839

#standard deviation of distances

sdbetadiversityG.WS <- sd(betadiversityGdata.WS) #0.12

ASVnogenus.WS <- tax.WS$Genus[grep("uncl", tax.WS$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.WS <- length(ASVnogenus.WS) #703

#% ASVs with no genus ID

PCASVnogenus.WS <- 703/1857 #38% 

################################Windmill Park ####################################################################################################################################
#prune empty taxa
ps.s.WP <- prune_taxa(taxa_sums(ps.s.WP) > 0, ps.s.WP)

#genera ID by pipeline
tax.WP <- as.data.frame(tax_table(ps.s.WP))
no.genus.WP <- length(unique(tax.WP$Genus)) #404

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.WP <- tax_glom(ps.s.WP, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.WP = plot_richness(genussummary.WP,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.WP + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.WP = data.table(pAlphaG.WP$data)

#subset to just observed
alphadtO.WP <- alphadt.WP[(variable == "Observed")]
# Calc mean observed
meanobserved.WP <- mean(alphadtO.WP$value) #136.67
# Subset to just the Chao1 index
alphadtC.WP <- alphadt.WP[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.WP <- mean(alphadtC.WP$value) #148.87
#subset to just Shannon
alphadtS.WP <- alphadt.WP[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.WP <- mean(alphadtS.WP$value) #2.47
#Calc exp of Shannon (Hill no D1)
expshannon.WP <- exp(meanshannon.WP) #11.86
#subset to just inv simpson
alphadtI.WP <- alphadt.WP[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.WP <- filter(alphadtI.WP, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.WP <- mean(alphadtI2.WP$value) #10.16

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.WP <- t(otu_table(genussummary.WP))
betadiversityG.WP <- vegdist(OTU.tableG.WP, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.WP <- as.matrix(betadiversityG.WP) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.WP)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.WP) #6
betadiversityGdata.WP<-t(matrix(t(betadiversityGdata.WP)[which(!is.na(betadiversityGdata.WP))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.WP <- mean(betadiversityGdata.WP) #0.82

#Median of distances  
medianbetadiversityG.WP <- median(betadiversityGdata.WP) #0.83

#range of distances
rangebetadiversityG.WP <- range(betadiversityGdata.WP) #0.584 - 1

#standard deviation of distances

sdbetadiversityG.WP <- sd(betadiversityGdata.WP) #0.15

ASVnogenus.WP <- tax.WP$Genus[grep("uncl", tax.WP$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.WP <- length(ASVnogenus.WP) #512

#% ASVs with no genus ID

PCASVnogenus.WP <- 512/1567 #33%

###############################################################################################################################################################################

#save workspace

save.image("~/Desktop/Parks16S/USEARCHSILVA/Parks16SUSEARCHSILVABPSnocontrols120521.RData")

#summary table

#create matrix
USEARCHSILVA16Ssummary.metrics <- matrix(c(no.genus.AS, no.genus.CP, no.genus.FF, no.genus.KH, no.genus.MA, no.genus.ME, no.genus.RL, no.genus.TM, no.genus.WF, no.genus.WS, no.genus.WP, meanobserved.AS, meanobserved.CP, meanobserved.FF, meanobserved.KH, meanobserved.MA, meanobserved.ME, meanobserved.RL, meanobserved.TM, meanobserved.WF, meanobserved.WS, meanobserved.WP, meanChao1.AS, meanChao1.CP, meanChao1.FF, meanChao1.KH, meanChao1.MA, meanChao1.ME, meanChao1.RL, meanChao1.TM, meanChao1.WF, meanChao1.WS, meanChao1.WP, meanshannon.AS, meanshannon.CP, meanshannon.FF, meanshannon.KH, meanshannon.MA, meanshannon.ME, meanshannon.RL, meanshannon.TM, meanshannon.WF, meanshannon.WS, meanshannon.WP, expshannon.AS, expshannon.CP, expshannon.FF, expshannon.KH, expshannon.MA, expshannon.ME, expshannon.RL, expshannon.TM, expshannon.WF, expshannon.WS, expshannon.WP, meaninvsimp.AS, meaninvsimp.CP, meaninvsimp.FF, meaninvsimp.KH, meaninvsimp.MA, meaninvsimp.ME, meaninvsimp.RL, meaninvsimp.TM, meaninvsimp.WF, meaninvsimp.WS, meaninvsimp.WP, meanbetadiversityG.AS, meanbetadiversityG.CP, meanbetadiversityG.FF, meanbetadiversityG.KH, meanbetadiversityG.MA, meanbetadiversityG.ME, meanbetadiversityG.RL, meanbetadiversityG.TM, meanbetadiversityG.WF, meanbetadiversityG.WS, meanbetadiversityG.WP, medianbetadiversityG.AS, medianbetadiversityG.CP, medianbetadiversityG.FF, medianbetadiversityG.KH, medianbetadiversityG.MA, medianbetadiversityG.ME, medianbetadiversityG.RL, medianbetadiversityG.TM, medianbetadiversityG.WF, medianbetadiversityG.WS, medianbetadiversityG.WP, "0.421 - 1", "0.502 - 1", "0.61 - 0.999", "0.368 - 0.996", "0.193 - 0.958", "0.31 - 0.921", "0.394 - 1", "0.552 - 1", "0.367 - 0.882", "0.353 - 0.839", "0.584 - 1", sdbetadiversityG.AS, sdbetadiversityG.CP, sdbetadiversityG.FF, sdbetadiversityG.KH, sdbetadiversityG.MA, sdbetadiversityG.ME, sdbetadiversityG.RL, sdbetadiversityG.TM, sdbetadiversityG.WF, sdbetadiversityG.WS, sdbetadiversityG.WP, no.ASVnogenus.AS, no.ASVnogenus.CP, no.ASVnogenus.FF, no.ASVnogenus.KH, no.ASVnogenus.MA, no.ASVnogenus.ME, no.ASVnogenus.RL, no.ASVnogenus.TM, no.ASVnogenus.WF, no.ASVnogenus.WS, no.ASVnogenus.WP, PCASVnogenus.AS, PCASVnogenus.CP, PCASVnogenus.FF, PCASVnogenus.KH, PCASVnogenus.MA, PCASVnogenus.ME, PCASVnogenus.RL, PCASVnogenus.TM, PCASVnogenus.WF, PCASVnogenus.WS, PCASVnogenus.WP), ncol=11, byrow=TRUE)

#define column names and row names of matrix
colnames(USEARCHSILVA16Ssummary.metrics) <- c('Aotea Square', 'Cornwall Park', 'Fijoa Forest', 'Keith Hay Park', 'Mt Albert Park', 'Mount Eden Domain', 'Rural location', 'The Museum', 'Warren Freer Park', 'Western Springs', 'Windmill Park')

rownames(USEARCHSILVA16Ssummary.metrics) <- c('16S USEARCH SILVA taxa - no. of genus', '16S USEARCH SILVA taxa - mean observed', '16S USEARCH SILVA taxa - mean Chao1', '16S USEARCH SILVA taxa - mean Shannon', '16S USEARCH SILVA taxa - exp Shannon', '16S USEARCH SILVA taxa - mean inv simpson', '16S USEARCH SILVA taxa - mean beta diversity', '16S USEARCH SILVA taxa - median beta diversity', '16S USEARCH SILVA taxa - range beta diversity', '16S USEARCH SILVA taxa - SD beta diversity', '16S USEARCH SILVA taxa - no. ASV with no genus', '16S USEARCH SILVA taxa - % ASV with no genus') #one row for each metric

# Save an object in RData format
save(USEARCHSILVA16Ssummary.metrics, file = "~/Desktop/Parks16S/USEARCHSILVA/USEARCHSILVA16Ssummary.RData")

#save workspace

save.image("~/Desktop/Parks16S/USEARCHSILVA/Parks16SUSEARCHSILVABPSnocontrols120521.RData")



