  options(echo=TRUE) # Enable output in Rscript for debugging
  library("dada2")
  library("phyloseq")
  library("magrittr")
  
  
  print("This script is current set to process fasta sequences in the directory it resides.")
  path <- getwd()
  print(paste("Executing DADA2 processing script in:", path))
  
  fnFs <- sort(list.files(path, pattern="_R1_001.fastq", full.names = TRUE))
  fnRs <- sort(list.files(path, pattern="_R2_001.fastq", full.names = TRUE))
  
      print("Cutadapt preprocessing to remove F&R primer sequences")
      dir.create(file.path("trimmed"), showWarnings = TRUE)
      
      for(i in 1:length(fnFs)){
      system2("cutadapt",paste0("-g CCTACGGGNGGCWGCAG -G GACTACHVGGGTATCTAATCC -o trimmed/", basename(fnFs[i]), " -p trimmed/", basename(fnRs[i]), " ", fnFs[i], " ", fnRs[i]))
      }
      
      print("Completed preprocessing!")

  #separating cutadapt and rest of Dada2 to assure primers removed
      
  setwd("~/Desktop/Parks16S/USEARCH/trimmed") #update working directory to the new trimmed sub-folder
      
  #rerun first bit of code to update path
  
  print("This script is current set to process fasta sequences in the directory it resides.")
  path <- getwd()
  print(paste("Executing DADA2 processing script in:", path))
  
  fnFs <- sort(list.files(path, pattern="_R1_001.fastq", full.names = TRUE))
  fnRs <- sort(list.files(path, pattern="_R2_001.fastq", full.names = TRUE))
  
  #or update names so sample names align with USEARCH output - may need updaing depending on the structure of the filenames
  
  sample_names <- sapply(strsplit(basename(fnFs), "_"), `[`, 1)
  
  # Diagnostic plot, can turn it on or off
  #plotQualityProfile(fnFs[37:48]) #On review reads look decent, quality drops off around 280 as usual.
  #plotQualityProfile(fnRs[37:48]) #Reverse reads poorer quality as ususal, simialr to forward reads, 250 looks fine.
  
  filt_path <- file.path(path, "filtered") # Place filtered files in filtered/ subdirectory
  filtFs <- file.path(filt_path, paste0(sample_names, "_F_filt.fastq.gz"))
  filtRs <- file.path(filt_path, paste0(sample_names, "_R_filt.fastq.gz"))
  
  #filter
   out <- filterAndTrim(fnFs, filtFs, fnRs, filtRs, truncLen=c(280,250),
                 		maxN=0, maxEE=c(2,5), truncQ=2, rm.phix=TRUE,
                 		compress=TRUE, multithread=TRUE)
  print(paste0(round(sum(out[,2] / out[,1])/nrow(out) * 100, digits=2), "% of reads passed filtering"))
  print("Based on a rule of thumb, proceed only if the majority (>50%) of reads passed filtering.") #Rethink parameters if lots of reads don't survive filtering.
  
  # This checks and removes files that did not survive filtering from from the filter output list - not needed in this case for 16S but needed if some samples totally fail
  
  #existsF <- file.exists(filtFs)
  #existsR	<- file.exists(filtRs)
  #filtFs <- filtFs[existsF]
  #filtRs <- filtRs[existsR] 
  
  errF <- learnErrors(filtFs, multithread=TRUE) #learn error rates
  errR <- learnErrors(filtRs, multithread=TRUE)
  
  derepFs <- derepFastq(filtFs, verbose=TRUE)
  derepRs <- derepFastq(filtRs, verbose=TRUE)
  
  # Name the derep-class objects by the sample names
  names(derepFs) <- sample_names
  names(derepRs) <- sample_names
  
  #denoise with Dada2
  dadaFs <- dada(derepFs, err=errF, multithread=TRUE) 
  dadaRs <- dada(derepRs, err=errR, multithread=TRUE)
  
  #Merge reads
  mergers <- mergePairs(dadaFs, derepFs, dadaRs, derepRs, verbose=TRUE)
  
  #make seq table
  
  seqtab <- makeSequenceTable(mergers)
 
   #dim(seqtab)
  table(nchar(getSequences(seqtab)))
  
  #select size range to keep 
  seqtab2 <- seqtab[,nchar(colnames(seqtab)) %in% 401:429]
  
  # Remove chimeras. 
  seqtab.nochim <- removeBimeraDenovo(seqtab2, method="consensus", multithread=TRUE, verbose=TRUE)
  
  print(paste0(round((1 - sum(seqtab.nochim)/sum(seqtab)) * 100, digits=2), "% of filtered reads were flagged as chimera")) #Rethink if a large porportion of reads are flagged as chimeras
  
  print("Generate diagnostic data frame")
  getN <- function(x) sum(getUniques(x))
  track <- cbind(out, sapply(dadaFs, getN), sapply(mergers, getN), rowSums(seqtab), rowSums(seqtab.nochim))
  
  # If processing a single sample, remove the sapply calls: e.g. replace sapply(dadaFs, getN) with getN(dadaFs)
  colnames(track) <- c("input", "filtered", "denoised", "merged", "tabled", "nonchim")
  rownames(track) <- sample_names
  track
  
  
write.csv(track,"16SDada2parks11203.csv", row.names = TRUE)
#Assign taxonomy
  taxa.RDP <- assignTaxonomy(seqtab.nochim, "~/Desktop/R/rdp_train_set_16.fa.gz", multithread=TRUE) #update to where database is stored
  taxa.RDP <- addSpecies(taxa.RDP, "~/Desktop/R/rdp_species_assignment_16.fa.gz")
  taxa.RDP.print <- taxa.RDP # Removing sequence rownames for display only
  rownames(taxa.RDP.print) <- NULL
  taxa.RDP.print
    
  #Build phyloseq
  psnop <-phyloseq (otu_table(seqtab.nochim, taxa_are_rows=FALSE))
  
  #Export OTU table for comparison to USEARCH
  psnop2 <- as.data.frame(psnop)  
  psnop3 <- t(psnop2)
  write.csv(psnop3, file = "16Sdada2parksnopASVs0105.csv")
  save(psnop, track, file="16Sdada2parksOTU0105.Rda")
