#load packages
library("phyloseq")

#Set working directory

setwd("~/Desktop/ParksITS/USEARCH")               

#look at taxonomy

load("parksITSusearch2404.Rda")

#prune out controls - not used for BPS stats
ps.s = subset_samples(ps, All.controls == "Sample") 

#genera ID by pipeline

tax <- as.data.frame(tax_table(ps.s))
no.genus <- length(unique(tax$Genus)) #501

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV

genussummary <- tax_glom(ps.s, taxrank = "Genus")

taxgenus <- as.data.frame(otu_table(genussummary))

##Calculate the same metrics per genus as was done per ASV

#Alpha diversity
library(ggplot2)

pAlphaG = plot_richness(genussummary,
                       shape = "Control.type",
                       color = "Location",
                       measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                       title = "Alpha Diveristy")
pAlphaG + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt = data.table(pAlphaG$data)

#subset to just observed
alphadtO <- alphadt[(variable == "Observed")]
# Calc mean observed
meanobserved <- mean(alphadtO$value) #121
# Subset to just the Chao1 index
alphadtC <- alphadt[(variable == "Chao1")]
# Calc mean Chao1
meanChao1 <- mean(alphadtC$value) #129
#subset to just Shannon
alphadtS <- alphadt[(variable == "Shannon")]
# Calc mean Shannon
meanshannon <- mean(alphadtS$value) #2.64
#Calc exp of Shannon (Hill no D1)
expshannon <- exp(meanshannon) #14
#subset to just inv simpson
alphadtI <- alphadt[(variable == "InvSimpson")]
library(dplyr)
alphadtI2 <- filter(alphadtI, value!= "Inf")#Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp <- mean(alphadtI2$value) #8.71

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG <- t(otu_table(genussummary))
betadiversityG <- vegdist(OTU.tableG, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata <- as.matrix(betadiversityG) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata) #67
betadiversityGdata<-t(matrix(t(betadiversityGdata)[which(!is.na(betadiversityGdata))],nrow=67,ncol=66)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG <- mean(betadiversityGdata) #0.84

#Median of distances
medianbetadiversityG <- median(betadiversityGdata) #0.86

#range of distances
rangebetadiversityG <- range(betadiversityGdata) #0.165 - 1

#standard deviation of distances

sdbetadiversityG <- sd(betadiversityGdata) #0.14

#no ASVs with no genus assigned

ASVnogenus <- tax$Genus[grep("uncl", tax$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus <- length(ASVnogenus) #3899

#% ASVs with no genus ID

PCASVnogenus <- 3899/5519 #0.71

#Save workspace

save.image("~/Desktop/ParksITS/USEARCH/ParksITSUSEARCHRDPBPSnocontrols.RData")

#########################################################################################################################################################################
#Calculate breakdown of indicators by Park for mann-whitney U test to test statistical significant of differences in stats between pipelines

load("~/Desktop/ParksITS/USEARCH/ParksITSUSEARCHRDPBPSnocontrols.RData")

#filter samples by park, then run above on each park

ps.s.AS <- subset_samples(ps.s, Location == "Aotea Square ") #needs a space at the end
ps.s.CP <- subset_samples(ps.s, Location == "Cornwall Park") 
ps.s.FF <- subset_samples(ps.s, Location == "Fijoa Forest")
ps.s.KH <- subset_samples(ps.s, Location == "Keith Hay Park")
ps.s.MA <- subset_samples(ps.s, Location == "Mt Albert Park")
ps.s.ME <- subset_samples(ps.s, Location == "Mt Eden Domain")
ps.s.RL <- subset_samples(ps.s, Location == "Rural location")
ps.s.TM <- subset_samples(ps.s, Location == "The Museum")
ps.s.WF <- subset_samples(ps.s, Location == "Warren Freer Park")
ps.s.WS <- subset_samples(ps.s, Location == "Western Springs")
ps.s.WP <- subset_samples(ps.s, Location == "Windmill Park")

################################ Aotea Square ###################################################################################################################################
#prune empty taxa
ps.s.AS <- prune_taxa(taxa_sums(ps.s.AS) > 0, ps.s.AS)

#genera ID by pipeline
tax.AS <- as.data.frame(tax_table(ps.s.AS))
no.genus.AS <- length(unique(tax.AS$Genus)) #142   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.AS <- tax_glom(ps.s.AS, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.AS = plot_richness(genussummary.AS,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.AS + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.AS = data.table(pAlphaG.AS$data)

#subset to just observed
alphadtO.AS <- alphadt.AS[(variable == "Observed")]
# Calc mean observed
meanobserved.AS <- mean(alphadtO.AS$value) #63.25
# Subset to just the Chao1 index
alphadtC.AS <- alphadt.AS[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.AS <- mean(alphadtC.AS$value) #63.36
#subset to just Shannon
alphadtS.AS <- alphadt.AS[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.AS <- mean(alphadtS.AS$value) #2.05
#Calc exp of Shannon (Hill no D1)
expshannon.AS <- exp(meanshannon.AS) #7.80
#subset to just inv simpson
alphadtI.AS <- alphadt.AS[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.AS <- filter(alphadtI.AS, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.AS <- mean(alphadtI2.AS$value) #5.20

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.AS <- t(otu_table(genussummary.AS))
betadiversityG.AS <- vegdist(OTU.tableG.AS, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.AS <- as.matrix(betadiversityG.AS) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.AS)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.AS) #4
betadiversityGdata.AS<-t(matrix(t(betadiversityGdata.AS)[which(!is.na(betadiversityGdata.AS))],nrow=4,ncol=3)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.AS <- mean(betadiversityGdata.AS) #0.67

#Median of distances  
medianbetadiversityG.AS <- median(betadiversityGdata.AS) #0.74

#range of distances
rangebetadiversityG.AS <- range(betadiversityGdata.AS) #0.165 - 0.851

#standard deviation of distances

sdbetadiversityG.AS <- sd(betadiversityGdata.AS) #0.25

ASVnogenus.AS <- tax.AS$Genus[grep("uncl", tax.AS$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.AS <- length(ASVnogenus.AS) #240

#% ASVs with no genus ID

PCASVnogenus.AS <- 240/422 #57% - 252 is from the total no of rows in the otu and tax table for ps.s.AS

################################Cornwall Park ####################################################################################################################################
#prune empty taxa
ps.s.CP <- prune_taxa(taxa_sums(ps.s.CP) > 0, ps.s.CP)

#genera ID by pipeline
tax.CP <- as.data.frame(tax_table(ps.s.CP))
no.genus.CP <- length(unique(tax.CP$Genus)) #326   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.CP <- tax_glom(ps.s.CP, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.CP = plot_richness(genussummary.CP,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.CP + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.CP = data.table(pAlphaG.CP$data)

#subset to just observed
alphadtO.CP <- alphadt.CP[(variable == "Observed")]
# Calc mean observed
meanobserved.CP <- mean(alphadtO.CP$value) #127.67
# Subset to just the Chao1 index
alphadtC.CP <- alphadt.CP[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.CP <- mean(alphadtC.CP$value) #136.65
#subset to just Shannon
alphadtS.CP <- alphadt.CP[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.CP <- mean(alphadtS.CP$value) #1.86
#Calc exp of Shannon (Hill no D1)
expshannon.CP <- exp(meanshannon.CP) #6.43
#subset to just inv simpson
alphadtI.CP <- alphadt.CP[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.CP <- filter(alphadtI.CP, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.CP <- mean(alphadtI2.CP$value) #5.60

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.CP <- t(otu_table(genussummary.CP))
betadiversityG.CP <- vegdist(OTU.tableG.CP, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.CP <- as.matrix(betadiversityG.CP) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.CP)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.CP) #6
betadiversityGdata.CP<-t(matrix(t(betadiversityGdata.CP)[which(!is.na(betadiversityGdata.CP))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.CP <- mean(betadiversityGdata.CP) #0.85

#Median of distances  
medianbetadiversityG.CP <- median(betadiversityGdata.CP) #0.92

#range of distances
rangebetadiversityG.CP <- range(betadiversityGdata.CP) #0.186 - 1

#standard deviation of distances

sdbetadiversityG.CP <- sd(betadiversityGdata.CP) #0.21

ASVnogenus.CP <- tax.CP$Genus[grep("uncl", tax.CP$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.CP <- length(ASVnogenus.CP) #1422

#% ASVs with no genus ID

PCASVnogenus.CP <- 1422/2125 #67% 

################################Fijoa Forest #####################################################################################################################################
#prune empty taxa
ps.s.FF <- prune_taxa(taxa_sums(ps.s.FF) > 0, ps.s.FF)

#genera ID by pipeline
tax.FF <- as.data.frame(tax_table(ps.s.FF))
no.genus.FF <- length(unique(tax.FF$Genus)) #314   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.FF <- tax_glom(ps.s.FF, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.FF = plot_richness(genussummary.FF,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.FF + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.FF = data.table(pAlphaG.FF$data)

#subset to just observed
alphadtO.FF <- alphadt.FF[(variable == "Observed")]
# Calc mean observed
meanobserved.FF <- mean(alphadtO.FF$value) #135.4
# Subset to just the Chao1 index
alphadtC.FF <- alphadt.FF[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.FF <- mean(alphadtC.FF$value) #144.33
#subset to just Shannon
alphadtS.FF <- alphadt.FF[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.FF <- mean(alphadtS.FF$value) #2.55
#Calc exp of Shannon (Hill no D1)
expshannon.FF <- exp(meanshannon.FF) #12.76
#subset to just inv simpson
alphadtI.FF <- alphadt.FF[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.FF <- filter(alphadtI.FF, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.FF <- mean(alphadtI2.FF$value) #8.04

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.FF <- t(otu_table(genussummary.FF))
betadiversityG.FF <- vegdist(OTU.tableG.FF, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.FF <- as.matrix(betadiversityG.FF) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.FF)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.FF) #5
betadiversityGdata.FF<-t(matrix(t(betadiversityGdata.FF)[which(!is.na(betadiversityGdata.FF))],nrow=5,ncol=4)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.FF <- mean(betadiversityGdata.FF) #0.90

#Median of distances  
medianbetadiversityG.FF <- median(betadiversityGdata.FF) #0.91

#range of distances
rangebetadiversityG.FF <- range(betadiversityGdata.FF) #0.778 - 0.996

#standard deviation of distances

sdbetadiversityG.FF <- sd(betadiversityGdata.FF) #0.07

ASVnogenus.FF <- tax.FF$Genus[grep("uncl", tax.FF$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.FF <- length(ASVnogenus.FF) #1136

#% ASVs with no genus ID

PCASVnogenus.FF <- 769/1786 #43% 

################################Keith Hay Park ###################################################################################################################################
#prune empty taxa
ps.s.KH <- prune_taxa(taxa_sums(ps.s.KH) > 0, ps.s.KH)

#genera ID by pipeline
tax.KH <- as.data.frame(tax_table(ps.s.KH))
no.genus.KH <- length(unique(tax.KH$Genus)) #2964  

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.KH <- tax_glom(ps.s.KH, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.KH = plot_richness(genussummary.KH,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.KH + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.KH = data.table(pAlphaG.KH$data)

#subset to just observed
alphadtO.KH <- alphadt.KH[(variable == "Observed")]
# Calc mean observed
meanobserved.KH <- mean(alphadtO.KH$value) #114.71
# Subset to just the Chao1 index
alphadtC.KH <- alphadt.KH[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.KH <- mean(alphadtC.KH$value) #123.58
#subset to just Shannon
alphadtS.KH <- alphadt.KH[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.KH <- mean(alphadtS.KH$value) #2.30
#Calc exp of Shannon (Hill no D1)
expshannon.KH <- exp(meanshannon.KH) #9.95
#subset to just inv simpson
alphadtI.KH <- alphadt.KH[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.KH <- filter(alphadtI.KH, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.KH <- mean(alphadtI2.KH$value) #5.69

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.KH <- t(otu_table(genussummary.KH))
betadiversityG.KH <- vegdist(OTU.tableG.KH, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.KH <- as.matrix(betadiversityG.KH) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.KH)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.KH) #7
betadiversityGdata.KH<-t(matrix(t(betadiversityGdata.KH)[which(!is.na(betadiversityGdata.KH))],nrow=7,ncol=6)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.KH <- mean(betadiversityGdata.KH) #0.83

#Median of distances  
medianbetadiversityG.KH <- median(betadiversityGdata.KH) #0.84

#range of distances
rangebetadiversityG.KH <- range(betadiversityGdata.KH) #0.307 - 0.998

#standard deviation of distances

sdbetadiversityG.KH <- sd(betadiversityGdata.KH) #0.18

ASVnogenus.KH <- tax.KH$Genus[grep("uncl", tax.KH$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.KH <- length(ASVnogenus.KH) #1096

#% ASVs with no genus ID

PCASVnogenus.KH <- 1096/1666 #66% 

################################Mt Albert Park ###################################################################################################################################
#prune empty taxa
ps.s.MA <- prune_taxa(taxa_sums(ps.s.MA) > 0, ps.s.MA)

#genera ID by pipeline
tax.MA <- as.data.frame(tax_table(ps.s.MA))
no.genus.MA <- length(unique(tax.MA$Genus)) #291   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.MA <- tax_glom(ps.s.MA, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.MA = plot_richness(genussummary.MA,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.MA + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.MA = data.table(pAlphaG.MA$data)

#subset to just observed
alphadtO.MA <- alphadt.MA[(variable == "Observed")]
# Calc mean observed
meanobserved.MA <- mean(alphadtO.MA$value) #114.43
# Subset to just the Chao1 index
alphadtC.MA <- alphadt.MA[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.MA <- mean(alphadtC.MA$value) #122.52
#subset to just Shannon
alphadtS.MA <- alphadt.MA[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.MA <- mean(alphadtS.MA$value) #2.83
#Calc exp of Shannon (Hill no D1)
expshannon.MA <- exp(meanshannon.MA) #16.99
#subset to just inv simpson
alphadtI.MA <- alphadt.MA[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.MA <- filter(alphadtI.MA, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.MA <- mean(alphadtI2.MA$value) #9.85

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.MA <- t(otu_table(genussummary.MA))
betadiversityG.MA <- vegdist(OTU.tableG.MA, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.MA <- as.matrix(betadiversityG.MA) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.MA)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.MA) #7
betadiversityGdata.MA<-t(matrix(t(betadiversityGdata.MA)[which(!is.na(betadiversityGdata.MA))],nrow=7,ncol=6)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.MA <- mean(betadiversityGdata.MA) #0.85

#Median of distances  
medianbetadiversityG.MA <- median(betadiversityGdata.MA) #0.85

#range of distances
rangebetadiversityG.MA <- range(betadiversityGdata.MA) #0.592 - 0.996

#standard deviation of distances

sdbetadiversityG.MA <- sd(betadiversityGdata.MA) #0.12

ASVnogenus.MA <- tax.MA$Genus[grep("uncl", tax.MA$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.MA <- length(ASVnogenus.MA) #1062

#% ASVs with no genus ID

PCASVnogenus.MA <- 1062/1619 #66% 

################################Mount Eden Domain ################################################################################################################################
#prune empty taxa
ps.s.ME <- prune_taxa(taxa_sums(ps.s.ME) > 0, ps.s.ME)

#genera ID by pipeline
tax.ME <- as.data.frame(tax_table(ps.s.ME))
no.genus.ME <- length(unique(tax.ME$Genus)) #341   

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.ME <- tax_glom(ps.s.ME, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.ME = plot_richness(genussummary.ME,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.ME + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.ME = data.table(pAlphaG.ME$data)

#subset to just observed
alphadtO.ME <- alphadt.ME[(variable == "Observed")]
# Calc mean observed
meanobserved.ME <- mean(alphadtO.ME$value) #163.83
# Subset to just the Chao1 index
alphadtC.ME <- alphadt.ME[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.ME <- mean(alphadtC.ME$value) #171.35
#subset to just Shannon
alphadtS.ME <- alphadt.ME[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.ME <- mean(alphadtS.ME$value) #3.05
#Calc exp of Shannon (Hill no D1)
expshannon.ME <- exp(meanshannon.ME) #21.22
#subset to just inv simpson
alphadtI.ME <- alphadt.ME[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.ME <- filter(alphadtI.ME, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.ME <- mean(alphadtI2.ME$value) #10.69

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.ME <- t(otu_table(genussummary.ME))
betadiversityG.ME <- vegdist(OTU.tableG.ME, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.ME <- as.matrix(betadiversityG.ME) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.ME)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.ME) #6
betadiversityGdata.ME<-t(matrix(t(betadiversityGdata.ME)[which(!is.na(betadiversityGdata.ME))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.ME <- mean(betadiversityGdata.ME) #0.76

#Median of distances  
medianbetadiversityG.ME <- median(betadiversityGdata.ME) #0.80

#range of distances
rangebetadiversityG.ME <- range(betadiversityGdata.ME) #0.487 - 0.935

#standard deviation of distances

sdbetadiversityG.ME <- sd(betadiversityGdata.ME) #0.15

ASVnogenus.ME <- tax.CP$Genus[grep("uncl", tax.ME$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.ME <- length(ASVnogenus.ME) #1711

#% ASVs with no genus ID

PCASVnogenus.ME <- 1711/2496 #69% 

################################Rural location ###################################################################################################################################
#prune empty taxa
ps.s.RL <- prune_taxa(taxa_sums(ps.s.RL) > 0, ps.s.RL)

#genera ID by pipeline
tax.RL <- as.data.frame(tax_table(ps.s.RL))
no.genus.RL <- length(unique(tax.RL$Genus)) #280  

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.RL <- tax_glom(ps.s.RL, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.RL = plot_richness(genussummary.RL,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.RL + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.RL = data.table(pAlphaG.RL$data)

#subset to just observed
alphadtO.RL <- alphadt.RL[(variable == "Observed")]
# Calc mean observed
meanobserved.RL <- mean(alphadtO.RL$value) #110.5
# Subset to just the Chao1 index
alphadtC.RL <- alphadt.RL[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.RL <- mean(alphadtC.RL$value) #122.39
#subset to just Shannon
alphadtS.RL <- alphadt.RL[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.RL <- mean(alphadtS.RL$value) #2.79
#Calc exp of Shannon (Hill no D1)
expshannon.RL <- exp(meanshannon.RL) #16.34
#subset to just inv simpson
alphadtI.RL <- alphadt.RL[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.RL <- filter(alphadtI.RL, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.RL <- mean(alphadtI2.RL$value) #8.39

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.RL <- t(otu_table(genussummary.RL))
betadiversityG.RL <- vegdist(OTU.tableG.RL, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.RL <- as.matrix(betadiversityG.RL) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.RL)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.RL) #6
betadiversityGdata.RL<-t(matrix(t(betadiversityGdata.RL)[which(!is.na(betadiversityGdata.RL))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.RL <- mean(betadiversityGdata.RL) #0.89

#Median of distances  
medianbetadiversityG.RL <- median(betadiversityGdata.RL) #0.90

#range of distances
rangebetadiversityG.RL <- range(betadiversityGdata.RL) #0.718 - 0.999

#standard deviation of distances

sdbetadiversityG.RL <- sd(betadiversityGdata.RL) #0.10

ASVnogenus.RL <- tax.CP$Genus[grep("uncl", tax.RL$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.RL <- length(ASVnogenus.RL) #1097

#% ASVs with no genus ID

PCASVnogenus.RL <- 1097/1646 #67% 

################################The Museum #####################################################################################################################################
#prune empty taxa
ps.s.TM <- prune_taxa(taxa_sums(ps.s.TM) > 0, ps.s.TM)

#genera ID by pipeline
tax.TM <- as.data.frame(tax_table(ps.s.TM))
no.genus.TM <- length(unique(tax.TM$Genus)) #259  

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.TM <- tax_glom(ps.s.TM, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.TM = plot_richness(genussummary.TM,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.TM + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.TM = data.table(pAlphaG.TM$data)

#subset to just observed
alphadtO.TM <- alphadt.TM[(variable == "Observed")]
# Calc mean observed
meanobserved.TM <- mean(alphadtO.TM$value) #90.33
# Subset to just the Chao1 index
alphadtC.TM <- alphadt.TM[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.TM <- mean(alphadtC.TM$value) #95.30
#subset to just Shannon
alphadtS.TM <- alphadt.TM[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.TM <- mean(alphadtS.TM$value) #2.80
#Calc exp of Shannon (Hill no D1)
expshannon.TM <- exp(meanshannon.TM) #16.40
#subset to just inv simpson
alphadtI.TM <- alphadt.TM[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.TM <- filter(alphadtI.TM, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.TM <- mean(alphadtI2.TM$value) #11.34

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.TM <- t(otu_table(genussummary.TM))
betadiversityG.TM <- vegdist(OTU.tableG.TM, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.TM <- as.matrix(betadiversityG.TM) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.TM)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.TM) #6
betadiversityGdata.TM<-t(matrix(t(betadiversityGdata.TM)[which(!is.na(betadiversityGdata.TM))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.TM <- mean(betadiversityGdata.TM) #0.91

#Median of distances  
medianbetadiversityG.TM <- median(betadiversityGdata.TM) #0.96

#range of distances
rangebetadiversityG.TM <- range(betadiversityGdata.TM) #0.611 - 1

#standard deviation of distances

sdbetadiversityG.TM <- sd(betadiversityGdata.TM) #0.11

ASVnogenus.TM <- tax.TM$Genus[grep("uncl", tax.TM$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.TM <- length(ASVnogenus.TM) #901

#% ASVs with no genus ID

PCASVnogenus.TM <- 901/1402 #64% 

################################Warren Freer Park ################################################################################################################################
#prune empty taxa
ps.s.WF <- prune_taxa(taxa_sums(ps.s.WF) > 0, ps.s.WF)

#genera ID by pipeline
tax.WF <- as.data.frame(tax_table(ps.s.WF))
no.genus.WF <- length(unique(tax.WF$Genus)) #310  

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.WF <- tax_glom(ps.s.WF, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.WF = plot_richness(genussummary.WF,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.WF + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.WF = data.table(pAlphaG.WF$data)

#subset to just observed
alphadtO.WF <- alphadt.WF[(variable == "Observed")]
# Calc mean observed
meanobserved.WF <- mean(alphadtO.WF$value) #116
# Subset to just the Chao1 index
alphadtC.WF <- alphadt.WF[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.WF <- mean(alphadtC.WF$value) #127.68
#subset to just Shannon
alphadtS.WF <- alphadt.WF[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.WF <- mean(alphadtS.WF$value) #2.64
#Calc exp of Shannon (Hill no D1)
expshannon.WF <- exp(meanshannon.WF) #14.03
#subset to just inv simpson
alphadtI.WF <- alphadt.WF[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.WF <- filter(alphadtI.WF, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.WF <- mean(alphadtI2.WF$value) #8.63

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.WF <- t(otu_table(genussummary.WF))
betadiversityG.WF <- vegdist(OTU.tableG.WF, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.WF <- as.matrix(betadiversityG.WF) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.WF)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.WF) #7
betadiversityGdata.WF<-t(matrix(t(betadiversityGdata.WF)[which(!is.na(betadiversityGdata.WF))],nrow=7,ncol=6)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.WF <- mean(betadiversityGdata.WF) #0.85

#Median of distances  
medianbetadiversityG.WF <- median(betadiversityGdata.WF) #0.88

#range of distances
rangebetadiversityG.WF <- range(betadiversityGdata.WF) #0.537 - 0.997

#standard deviation of distances

sdbetadiversityG.WF <- sd(betadiversityGdata.WF) #0.13

ASVnogenus.WF <- tax.WF$Genus[grep("uncl", tax.WF$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.WF <- length(ASVnogenus.WF) #1138

#% ASVs with no genus ID

PCASVnogenus.WF <- 1138/1770 #64% 

################################Western Springs ##################################################################################################################################
#prune empty taxa
ps.s.WS <- prune_taxa(taxa_sums(ps.s.WS) > 0, ps.s.WS)

#genera ID by pipeline
tax.WS <- as.data.frame(tax_table(ps.s.WS))
no.genus.WS <- length(unique(tax.WS$Genus)) #345 

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.WS <- tax_glom(ps.s.WS, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.WS = plot_richness(genussummary.WS,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.WS + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.WS = data.table(pAlphaG.WS$data)

#subset to just observed
alphadtO.WS <- alphadt.WS[(variable == "Observed")]
# Calc mean observed
meanobserved.WS <- mean(alphadtO.WS$value) #169.83
# Subset to just the Chao1 index
alphadtC.WS <- alphadt.WS[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.WS <- mean(alphadtC.WS$value) #176.55
#subset to just Shannon
alphadtS.WS <- alphadt.WS[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.WS <- mean(alphadtS.WS$value) #3.15
#Calc exp of Shannon (Hill no D1)
expshannon.WS <- exp(meanshannon.WS) #23.34
#subset to just inv simpson
alphadtI.WS <- alphadt.WS[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.WS <- filter(alphadtI.WS, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.WS <- mean(alphadtI2.WS$value) #12.31

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.WS <- t(otu_table(genussummary.WS))
betadiversityG.WS <- vegdist(OTU.tableG.WS, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.WS <- as.matrix(betadiversityG.WS) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.WS)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.WS) #6
betadiversityGdata.WS<-t(matrix(t(betadiversityGdata.WS)[which(!is.na(betadiversityGdata.WS))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.WS <- mean(betadiversityGdata.WS) #0.76

#Median of distances  
medianbetadiversityG.WS <- median(betadiversityGdata.WS) #0.76

#range of distances
rangebetadiversityG.WS <- range(betadiversityGdata.WS) #0.585 - 0.849

#standard deviation of distances

sdbetadiversityG.WS <- sd(betadiversityGdata.WS) #0.07

ASVnogenus.WS <- tax.WS$Genus[grep("uncl", tax.WS$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.WS <- length(ASVnogenus.WS) #1606

#% ASVs with no genus ID

PCASVnogenus.WS <- 1606/2409 #67% 

################################Windmill Park ####################################################################################################################################
#prune empty taxa
ps.s.WP <- prune_taxa(taxa_sums(ps.s.WP) > 0, ps.s.WP)

#genera ID by pipeline
tax.WP <- as.data.frame(tax_table(ps.s.WP))
no.genus.WP <- length(unique(tax.WP$Genus)) #290

#Diversity metrics per Genera
#make phyloseq summarised by genus rather than ASV
genussummary.WP <- tax_glom(ps.s.WP, taxrank = "Genus")

#Calculate the same metrics per genus as was done per ASV
#alpha diversity 
library(ggplot2)

pAlphaG.WP = plot_richness(genussummary.WP,
                           shape = "Control.type",
                           color = "Location",
                           measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                           title = "Alpha Diveristy")
pAlphaG.WP + geom_point(size = 5)

library(data.table)

# Store as a new data variable
alphadt.WP = data.table(pAlphaG.WP$data)

#subset to just observed
alphadtO.WP <- alphadt.WP[(variable == "Observed")]
# Calc mean observed
meanobserved.WP <- mean(alphadtO.WP$value) #116.33
# Subset to just the Chao1 index
alphadtC.WP <- alphadt.WP[(variable == "Chao1")]
# Calc mean Chao1
meanChao1.WP <- mean(alphadtC.WP$value) #124.44
#subset to just Shannon
alphadtS.WP <- alphadt.WP[(variable == "Shannon")]
# Calc mean Shannon
meanshannon.WP <- mean(alphadtS.WP$value) #2.80
#Calc exp of Shannon (Hill no D1)
expshannon.WP <- exp(meanshannon.WP) #16.41
#subset to just inv simpson
alphadtI.WP <- alphadt.WP[(variable == "InvSimpson")]
library(dplyr)
alphadtI2.WP <- filter(alphadtI.WP, value!= "Inf") #Samples which give infinity disrupt the mean so are filtered out
# Calc mean inv simpson
meaninvsimp.WP <- mean(alphadtI2.WP$value) #9.14

#Beta diversity Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#transpose OTU table
OTU.tableG.WP <- t(otu_table(genussummary.WP))
betadiversityG.WP <- vegdist(OTU.tableG.WP, method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversityGdata.WP <- as.matrix(betadiversityG.WP) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversityGdata.WP)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversityGdata.WP) #6
betadiversityGdata.WP<-t(matrix(t(betadiversityGdata.WP)[which(!is.na(betadiversityGdata.WP))],nrow=6,ncol=5)) #removes NAs from matrix

#Mean of distances
meanbetadiversityG.WP <- mean(betadiversityGdata.WP) #0.86

#Median of distances  
medianbetadiversityG.WP <- median(betadiversityGdata.WP) #0.91

#range of distances
rangebetadiversityG.WP <- range(betadiversityGdata.WP) #0.616 - 0.999

#standard deviation of distances

sdbetadiversityG.WP <- sd(betadiversityGdata.WP) #0.13

ASVnogenus.WP <- tax.WP$Genus[grep("uncl", tax.WP$Genus)] #subset ASVs with uncl = unclassifed somewhere in it - no genus ID
no.ASVnogenus.WP <- length(ASVnogenus.WP) #995

#% ASVs with no genus ID

PCASVnogenus.WP <- 995/1571 #63%

###############################################################################################################################################################################

#save workspace

save.image("~/Desktop/ParksITS/USEARCH/ParksITSUSEARCHRDPBPSnocontrols120521.RData")

#summary table

#create matrix
ITSUSEARCHRDPsummary.metrics <- matrix(c(no.genus.AS, no.genus.CP, no.genus.FF, no.genus.KH, no.genus.MA, no.genus.ME, no.genus.RL, no.genus.TM, no.genus.WF, no.genus.WS, no.genus.WP, meanobserved.AS, meanobserved.CP, meanobserved.FF, meanobserved.KH, meanobserved.MA, meanobserved.ME, meanobserved.RL, meanobserved.TM, meanobserved.WF, meanobserved.WS, meanobserved.WP, meanChao1.AS, meanChao1.CP, meanChao1.FF, meanChao1.KH, meanChao1.MA, meanChao1.ME, meanChao1.RL, meanChao1.TM, meanChao1.WF, meanChao1.WS, meanChao1.WP, meanshannon.AS, meanshannon.CP, meanshannon.FF, meanshannon.KH, meanshannon.MA, meanshannon.ME, meanshannon.RL, meanshannon.TM, meanshannon.WF, meanshannon.WS, meanshannon.WP, expshannon.AS, expshannon.CP, expshannon.FF, expshannon.KH, expshannon.MA, expshannon.ME, expshannon.RL, expshannon.TM, expshannon.WF, expshannon.WS, expshannon.WP, meaninvsimp.AS, meaninvsimp.CP, meaninvsimp.FF, meaninvsimp.KH, meaninvsimp.MA, meaninvsimp.ME, meaninvsimp.RL, meaninvsimp.TM, meaninvsimp.WF, meaninvsimp.WS, meaninvsimp.WP, meanbetadiversityG.AS, meanbetadiversityG.CP, meanbetadiversityG.FF, meanbetadiversityG.KH, meanbetadiversityG.MA, meanbetadiversityG.ME, meanbetadiversityG.RL, meanbetadiversityG.TM, meanbetadiversityG.WF, meanbetadiversityG.WS, meanbetadiversityG.WP, medianbetadiversityG.AS, medianbetadiversityG.CP, medianbetadiversityG.FF, medianbetadiversityG.KH, medianbetadiversityG.MA, medianbetadiversityG.ME, medianbetadiversityG.RL, medianbetadiversityG.TM, medianbetadiversityG.WF, medianbetadiversityG.WS, medianbetadiversityG.WP, "0.165 - 0.851", "0.186 - 1", "0.778 - 0.996", "0.307 - 0.998", "0.592 - 0.996", "0.487 - 0.935", "0.718 - 0.999", "0.611 - 1", "0.537 - 0.997", "0.585 - 0.849", "0.616 - 0.999", sdbetadiversityG.AS, sdbetadiversityG.CP, sdbetadiversityG.FF, sdbetadiversityG.KH, sdbetadiversityG.MA, sdbetadiversityG.ME, sdbetadiversityG.RL, sdbetadiversityG.TM, sdbetadiversityG.WF, sdbetadiversityG.WS, sdbetadiversityG.WP, no.ASVnogenus.AS, no.ASVnogenus.CP, no.ASVnogenus.FF, no.ASVnogenus.KH, no.ASVnogenus.MA, no.ASVnogenus.ME, no.ASVnogenus.RL, no.ASVnogenus.TM, no.ASVnogenus.WF, no.ASVnogenus.WS, no.ASVnogenus.WP, PCASVnogenus.AS, PCASVnogenus.CP, PCASVnogenus.FF, PCASVnogenus.KH, PCASVnogenus.MA, PCASVnogenus.ME, PCASVnogenus.RL, PCASVnogenus.TM, PCASVnogenus.WF, PCASVnogenus.WS, PCASVnogenus.WP), ncol=11, byrow=TRUE)

#define column names and row names of matrix
colnames(ITSUSEARCHRDPsummary.metrics) <- c('Aotea Square', 'Cornwall Park', 'Fijoa Forest', 'Keith Hay Park', 'Mt Albert Park', 'Mount Eden Domain', 'Rural location', 'The Museum', 'Warren Freer Park', 'Western Springs', 'Windmill Park')

rownames(ITSUSEARCHRDPsummary.metrics) <- c('ITS USEARCH RDP taxa - no. of genus', 'ITS USEARCH RDP taxa - mean observed', 'ITS USEARCH RDP taxa - mean Chao1', 'ITS USEARCH RDP taxa - mean Shannon', 'ITS USEARCH RDP taxa - exp Shannon', 'ITS USEARCH RDP taxa - mean inv simpson', 'ITS USEARCH RDP taxa - mean beta diversity', 'ITS USEARCH RDP taxa - median beta diversity', 'ITS USEARCH RDP taxa - range beta diversity', 'ITS USEARCH RDP taxa - SD beta diversity', 'ITS USEARCH RDP taxa - no. ASV with no genus', 'ITS USEARCH RDP taxa - % ASV with no genus') #one row for each metric

# Save an object in RData format
save(ITSUSEARCHRDPsummary.metrics, file = "~/Desktop/ParksITS/USEARCH/ITSUSEARCHRDPsummary.RData")

#save workspace

save.image("~/Desktop/ParksITS/USEARCH/ParksITSUSEARCHRDPBPSnocontrols120521.RData")



