#load packages
library(phyloseq)

#set working directory
setwd("~/Desktop/ParksITS")

#Bring in OTU table from Dada2 pipeline

OTU.Dada2 <- read.csv("ITSdada2parksnopASVs0405.csv", header = TRUE, sep=",", row.names = 1)

#Bring in OTU table for USEARCH

OTU.USEARCH <- read.csv("USEARCH/OTUwseqFinalUSEARCHITSParks1505.csv", header = TRUE, sep=",", row.names = 1)

#Venn diagrams
library(VennDiagram)

#Pull out a list of the ASV codes in each dataset

Dada2ASVs <- rownames(OTU.Dada2)
USEARCHASVs <- rownames(OTU.USEARCH)

#Plot Venn Diag

venn.plot <- venn.diagram(
  x = list(
    "Dada2 ASVs" = Dada2ASVs,
    "USEARCH ASVs" = USEARCHASVs
  ),
  filename = "Dada2vUsearchASVsITSforpub.png",
  lwd = 4,
  fill = c("cornflowerblue", "darkorchid1"),
  alpha = 0.75,
  label.col = "deeppink3",
  cex = 3,
  imagetype = "png",
  fontfamily = "serif",
  fontface = "bold",
  cat.col = c("cornflowerblue", "darkorchid1"),
  cat.cex = 2,
  cat.fontfamily = "serif",
  cat.fontface = "bold",
  cat.dist = c(0.03, 0.03),
  cat.pos = c(-20, 14),
  resolution = 300
);

#get lists of ASVs which make up the numbers in the venn diagram
#switch to vector

Dada2ASVsv <- unlist(Dada2ASVs)
USEARCHASVsv <- unlist(USEARCHASVs)

#What is in Both (Dada2 and USEARCH)
ASVsinboth <- intersect(Dada2ASVsv,USEARCHASVsv)

#What is different in USEARCH
ASVsinUSEARCH <- setdiff(USEARCHASVsv,Dada2ASVsv)

#What is different in Dada2
ASVsinDada2 <- setdiff(Dada2ASVsv,USEARCHASVsv)

#Use phyloseq to combine the two OTU tables
#rename columns in each so it is possible to differentiate the samples once the OTU tables are combined.

colnames(OTU.USEARCH) <- paste("USEARCH", colnames(OTU.USEARCH), sep = "_")
colnames(OTU.Dada2) <- paste("Dada2", colnames(OTU.Dada2), sep = "_")

#phyloseqize each OTU table

OTU.Dada2 = otu_table(OTU.Dada2, taxa_are_rows = TRUE) 
OTU.USEARCH = otu_table(OTU.USEARCH, taxa_are_rows = TRUE) 

ps <- merge_phyloseq(OTU.Dada2,OTU.USEARCH) #now has 8828 taxa - 3309 + 4198 + 1321 = 8828

#filter combined OTU table based on taxa in both, or either.

#ASVs that are in Dada2 and not USEARCH

OTU.Dada2.only <- otu_table(ps)[(ASVsinDada2), ]
OTU.Dada2.only <- as.data.frame(OTU.Dada2.only)

#most intersting to see if the Dada2 ones look spurious as there are many just in Dada2
#export to investigate if desired
#write.csv(OTU.Dada2.only, file="OTUDADA2only.csv")

#ASVs that are in USEARCH and not Dada2

OTU.USEARCH.only <- otu_table(ps)[(ASVsinUSEARCH), ]
OTU.USEARCH.only <- as.data.frame(OTU.USEARCH.only)

#export to investigate if desired
#write.csv(OTU.USEARCH.only, file="OTUUSEARCH2only.csv")

#ASVs that are in both

OTU.both <- otu_table(ps)[(ASVsinboth), ]
OTU.both <- as.data.frame(OTU.both)

#export to investigate if desired
#write.csv(OTU.both, file="OTUboth.csv")

#save workspace
save.image("~/Desktop/ParksITS/ITSParksDada2USEARCHASVscomp1805.RData")

