        options(echo=TRUE) # Enable output in Rscript for debugging
        library("dada2")
        library("phyloseq")
        library("magrittr")
        library(dada2)
        library(ShortRead)
        library(Biostrings)
 
        setwd("~/Desktop/ParksITS") #change as needed
        
        print("This script is current set to process fasta sequences in the directory it resides.")
        path <- getwd()
        print(paste("Executing DADA2 processing script in:", path))
        
        fnFs <- sort(list.files(path, pattern="_R1_001.fastq.gz", full.names = TRUE))
        fnRs <- sort(list.files(path, pattern="_R2_001.fastq.gz", full.names = TRUE))

        #check presence and oriantation of primers on the reads
        
        FWD <- "CTTGGTCATTTAGAGGAAGTAA" 
        REV <- "GCTGCGTTCTTCATCGATGC" 
        
        allOrients <- function(primer) {
                # Create all orientations of the input sequence
                require(Biostrings)
                dna <- DNAString(primer)  # The Biostrings works w/ DNAString objects rather than character vectors
                orients <- c(Forward = dna, Complement = complement(dna), Reverse = reverse(dna), 
                             RevComp = reverseComplement(dna))
                return(sapply(orients, toString))  # Convert back to character vector
        }
        FWD.orients <- allOrients(FWD)
        REV.orients <- allOrients(REV)
        FWD.orients
        
        #fileter out reads with N -  unclear nucleaotides. 
        
        fnFs.filtN <- file.path(path, "filtN", basename(fnFs)) # Put N-filterd files in filtN/ subdirectory
        fnRs.filtN <- file.path(path, "filtN", basename(fnRs))
        filterAndTrim(fnFs, fnFs.filtN, fnRs, fnRs.filtN, maxN = 0, multithread = TRUE)
        
        #Count no of times the primer appears in the reads in both its orientations (due to read through)
        
        primerHits <- function(primer, fn) {
                # Counts number of reads in which the primer is found
                nhits <- vcountPattern(primer, sread(readFastq(fn)), fixed = FALSE)
                return(sum(nhits > 0))
        }
        rbind(FWD.ForwardReads = sapply(FWD.orients, primerHits, fn = fnFs.filtN[[1]]), 
              FWD.ReverseReads = sapply(FWD.orients, primerHits, fn = fnRs.filtN[[1]]), 
              REV.ForwardReads = sapply(REV.orients, primerHits, fn = fnFs.filtN[[1]]), 
              REV.ReverseReads = sapply(REV.orients, primerHits, fn = fnRs.filtN[[1]]))

#call cutadapt        
cutadapt <- "/usr/local/bin/cutadapt" # CHANGE ME to the cutadapt path on your machine
system2(cutadapt, args = "--version")        

#run cutadapt        
path.cut <- file.path(path, "cutadapt")
if(!dir.exists(path.cut)) dir.create(path.cut)
fnFs.cut <- file.path(path.cut, basename(fnFs))
fnRs.cut <- file.path(path.cut, basename(fnRs))

FWD.RC <- dada2:::rc(FWD)
REV.RC <- dada2:::rc(REV)

# Trim FWD and the reverse-complement of REV off of R1 (forward reads)
R1.flags <- paste("-g", FWD, "-a", REV.RC) 

# Trim REV and the reverse-complement of FWD off of R2 (reverse reads)
R2.flags <- paste("-G", REV, "-A", FWD.RC) 

# Run Cutadapt
for(i in seq_along(fnFs)) {
        system2(cutadapt, args = c(R1.flags, R2.flags, "-n", 2, # -n 2 required to remove FWD and REV from reads
                                   "-o", fnFs.cut[i], "-p", fnRs.cut[i], # output files
                                   fnFs.filtN[i], fnRs.filtN[i])) # input files
}

#check cutadapt has correctly removed the primers

rbind(FWD.ForwardReads = sapply(FWD.orients, primerHits, fn = fnFs.cut[[1]]), 
      FWD.ReverseReads = sapply(FWD.orients, primerHits, fn = fnRs.cut[[1]]), 
      REV.ForwardReads = sapply(REV.orients, primerHits, fn = fnFs.cut[[1]]), 
      REV.ReverseReads = sapply(REV.orients, primerHits, fn = fnRs.cut[[1]]))

# Forward and reverse fastq filenames have the format:
cutFs <- sort(list.files(path.cut, pattern = "_R1_001.fastq.gz", full.names = TRUE))
cutRs <- sort(list.files(path.cut, pattern = "_R2_001.fastq.gz", full.names = TRUE))
        

# Extract sample names, this will need to be changed if filenames have a different format

sample_names <- sapply(strsplit(basename(fnFs), "_"), `[`, 1)

#filter
filtFs <- file.path(path.cut, "filtered", basename(cutFs))
filtRs <- file.path(path.cut, "filtered", basename(cutRs))

out <- filterAndTrim(cutFs, filtFs, cutRs, filtRs, maxN = 0, maxEE = c(2, 2), 
                     truncQ = 2, minLen = 50, rm.phix = TRUE, compress = TRUE, multithread = TRUE)  # on windows, set multithread = FALSE
#check out
head(out)

 # This checks and removes files that did not survive filtering from from the filter output list
 existsF <- file.exists(filtFs)
 existsR	<- file.exists(filtRs)
 filtFs <- filtFs[existsF]
 filtRs <- filtRs[existsR]

print(paste0(round(sum(out[,2] / out[,1])/nrow(out) * 100, digits=2), "% of reads passed filtering"))
print("Based on a rule of thumb, proceed only if the majority (>50%) of reads passed filtering.") #check if many reads fail filtering

errF <- learnErrors(filtFs, multithread=TRUE)
errR <- learnErrors(filtRs, multithread=TRUE)

derepFs <- derepFastq(filtFs, verbose=TRUE)
derepRs <- derepFastq(filtRs, verbose=TRUE)

# If naming the derep-class objects by the sample names doesn't work because the vectors are different lengths. Using the below code will fix the issue.
names(derepFs) <- sample_names[existsF]
names(derepRs) <- sample_names[existsR]

dadaFs <- dada(derepFs, err=errF, multithread=TRUE)
dadaRs <- dada(derepRs, err=errR, multithread=TRUE)

mergers <- mergePairs(dadaFs, derepFs, dadaRs, derepRs, verbose=TRUE)

seqtab <- makeSequenceTable(mergers)

seqtab.nochim <- removeBimeraDenovo(seqtab, method="consensus", multithread=TRUE, verbose=TRUE)

print(paste0(round((1 - sum(seqtab.nochim)/sum(seqtab)) * 100, digits=2), "% of filtered reads were flagged as chimera")) #Check if many chimeras flagged

        print("Generate diagnostic data frame")
        getN <- function(x) sum(getUniques(x))
        track <- cbind(out, sapply(dadaFs, getN), sapply(mergers, getN), rowSums(seqtab), rowSums(seqtab.nochim))
        
        # If processing a single sample, remove the sapply calls: e.g. replace sapply(dadaFs, getN) with getN(dadaFs)
        colnames(track) <- c("input", "filtered", "denoised", "merged", "tabled", "nonchim")
        rownames(track) <- sample_names
        track
        
        #write.csv(track,"ITSDada2parksnoprim0205.csv", row.names = TRUE)
        
        taxa.unite <- assignTaxonomy(seqtab.nochim, "~/Desktop/R/uniteits.fasta", multithread=TRUE) #change path to database
        
        #Build phyloseq object
        
        ps <- phyloseq(otu_table(seqtab.nochim, taxa_are_rows=FALSE), tax_table(taxa.unite))
        
        save(ps, track, file="ITSDada2parks1903.Rda")
        
        #Build OTU table that can be compared to USEARCH
        psnop <-phyloseq (otu_table(seqtab.nochim, taxa_are_rows=FALSE))
        psnop2 <- as.data.frame(psnop)  
        psnop3 <- t(psnop2)
        write.csv(psnop3, file = "ITSdada2parksnopASVs0405.csv")
        save(psnop, track, file="ITSdada2parksOTU0405.Rda")