#load packages
library(phyloseq)

#Set working directory
setwd("~/Desktop/ParksITS/USEARCH")

#Load file
load("/home/katie/Desktop/ParksITS/USEARCH/ParksITSUSEARCHBBPS1905.Rda") #phyloseq with combined tax table

#load Decomtam 
library(decontam)

#inspect read count
library(ggplot2)

df <- as.data.frame(sample_data(ps.TU)) # Put sample_data into a ggplot-friendly data.frame
df$LibrarySize <- sample_sums(ps.TU)
df <- df[order(df$LibrarySize),]
df$Index <- seq(nrow(df))
ggplot(data=df, aes(x=Index, y=LibrarySize, color=All.controls)) + geom_point() #negative samples have lower reads as expected

#methods for contamination ID compared

#frequency
contamdf.freq <- isContaminant(ps.TU, method="frequency", conc="DNA.quant.post.ITS.PCR") #update quant_reading to be where the quant info is stored in the metedata

table(contamdf.freq$contaminant)

#found 104. 5415 OK.

#combo method

sample_data(ps.TU)$is.neg <- sample_data(ps.TU)$All.controls == "Control" #update for fields that are controls
contamdf.combo <- isContaminant(ps.TU, method="combined", conc="DNA.quant.post.ITS.PCR", neg="is.neg", threshold = 0.5) #upper threshold

table(contamdf.combo$contaminant)

#found 251. 5268 OK.

#prevelance method - lower threshold

contamdf.prev01 <- isContaminant(ps.TU, method="prevalence", neg="is.neg")
table(contamdf.prev01$contaminant) #1 Taxa ID, 5518 OK

#prevelance method - higher threshold

contamdf.prev05 <- isContaminant(ps.TU, method="prevalence", neg="is.neg", threshold=0.5)
table(contamdf.prev05$contaminant) #77 ID, 5442 OK

#try with extraction and pcr -vs only

#update control samples 
sample_data(ps.TU)$is.neg <- sample_data(ps.TU)$Lab.controls == "Control" 

contamdfE.prev01 <- isContaminant(ps.TU, method="prevalence", neg="is.neg")
table(contamdfE.prev01$contaminant) #8 ID with extraction controls onwards

#retry with stricter filtering criteria

contamdfE.prev05 <- isContaminant(ps.TU, method="prevalence", neg="is.neg", threshold=0.5)
table(contamdfE.prev05$contaminant) #50 ID with extraction controls onwards

#Microdecon

#load package
library("microDecon")

#Microdecon just needs the OTU table, but with columns reordered with negatives first and then each location together, and columns with 0s removed. 

OTUtab.M <- as.data.frame (otu_table(ps.TU))

#rearrange columns. One less as PCR +ve control left out.

library(dplyr)
OTUtab.M2 <- OTUtab.M %>% select(KA117, KA122, KA123, KA125, KA129, KA131, KA132, KA135, KA139, KA141, KA146, KA150, KA155, KA157, KA161, KA164, KA168, KA172, KA195, KA226, KA228, KA232, KA236, KA237, KA241, KA245, KA247, KA251, KA288, KA118, KA119, KA120, KA231, KA145, KA148, KA163, KA224, KA250, KA269, KA153, KA156, KA165, KA233, KA265, KA142, KA149, KA154, KA159, KA240, KA244, KA252, KA126, KA134, KA138, KA158, KA171, KA167, KA235, KA128, KA140, KA151, KA238, KA243, KA272, KA116, KA121, KA229, KA230, KA242, KA268, KA144, KA152, KA166, KA227, KA234, KA264, KA127, KA133, KA136, KA169, KA248, KA267, KA271, KA124, KA130, KA137, KA160, KA170, KA246, KA143, KA147, KA162, KA239, KA249, KA266)
#one diff is the PCR +ve
#move ASVs out of row names for compatability with microdecon

library(tibble)
OTUtab.M2 <- rownames_to_column(OTUtab.M2, "ASV")

#run microDecon on defaults grouped by park

decontaminated <- decon(data=OTUtab.M2,numb.blanks=29,numb.ind=c(4,6,5,7,7,6,6,6,7,6,6), taxa=F)

#check output

deconOTUs <- decontaminated$decon.table #decontaminated OTU table
readsremoved <- decontaminated$reads.removed #info on reads taken out of each sample
readsremovedgroup <- decontaminated$sum.per.group # total reads removed from each otu
averagereadsremoved <- decontaminated$mean.per.group # average reads removed from each otu
OTUsremoved <- decontaminated$OTUs.removed #OTUs that have been completly removed

#If desired review decontamination by both methods by creating decontaminated OTU table with ASV flags to make sure there isn't lots of something that is probably a contaminant remaining

#put ASV into the first column of the decontam outputs so joining will work

contamdf.combo <- rownames_to_column(contamdf.combo, "ASV")
contamdf.freq <- rownames_to_column(contamdf.freq, "ASV")
contamdf.prev01 <- rownames_to_column(contamdf.prev01, "ASV")
contamdf.prev05 <- rownames_to_column(contamdf.prev05, "ASV")
contamdfE.prev01 <- rownames_to_column(contamdfE.prev01, "ASV")
contamdfE.prev05 <- rownames_to_column(contamdfE.prev05, "ASV")

#rename contamination column in each so they are distingushable on merge

contamdf.combo$Combo.contaminant <- contamdf.combo$contaminant
contamdf.freq$Freq.contaminant <- contamdf.freq$contaminant
contamdf.prev01$Prev.0.1.All.controls.contaminant <- contamdf.prev01$contaminant
contamdf.prev05$Prev.0.5.All.controls.contaminant <- contamdf.prev05$contaminant
contamdfE.prev01$Prev.0.1.Lab.controls.contaminant <- contamdfE.prev01$contaminant
contamdfE.prev05$Prev.0.5.Lab.controls.contaminant <- contamdfE.prev05$contaminant

#remove columns not needed in below report for each of the above

contamdf.combo <- contamdf.combo[-c(2:7)]
contamdf.freq <- contamdf.freq[-c(2:7)]
contamdf.prev01 <- contamdf.prev01[-c(2:7)]
contamdf.prev05 <- contamdf.prev05[-c(2:7)]
contamdfE.prev01 <- contamdfE.prev01[-c(2:7)]
contamdfE.prev05 <- contamdfE.prev05[-c(2:7)]

#Pull out tax table and put ASV in the first column

TAX <- as.data.frame(tax_table(ps.TU))
TAX <- rownames_to_column(TAX, "ASV")

library(dplyr)
Decontamination.report <- left_join(deconOTUs, TAX,  by = "ASV")
D1 <- left_join(contamdf.combo, contamdf.freq, by = "ASV")
D2 <- left_join(contamdf.prev01, contamdf.prev05, by = "ASV")
D3 <- left_join(contamdfE.prev01, contamdfE.prev05, by = "ASV")
D4 <- left_join(D1,D2, by = "ASV")
D5 <- left_join(D4,D3, by = "ASV")
Decontamination.report.F <- left_join(Decontamination.report,D5, by = "ASV")

#Export if desired

write.csv(Decontamination.report.F, file = "ParksITSUSEARCHBBcombodecontaminationreport2005.csv") 

#rebuild decontaminated ps with output decon$table. Use one without taxonomy for going back into phyloseq as that has the taxonomy seperatly. Note after decontamination negatives will be one average column rather then several columns and ASV order may vary or be shorter if whole ASVs were removed.

#reimport file with sums ect in it for further review. Get an undefined columns error if try to add across many in the OTU in R.

Decontaination.report.2 <- read.csv(file = "ParksITSUSEARCHBBcombodecontaminationreport2005.csv", header = TRUE)

#Build both checking reports

#Review of ASVs flagged as likely contaminants per the combined method, and the corresponding deduction made by microdecon to confirm that both approaches show consistancy and that micrfodecon has addressed all likely contaminants.

comp.MD.D <-filter(Decontaination.report.2, Combo.contaminant=="TRUE")
comp.MD.D <- select(comp.MD.D, ASV, Mean.blank, Total.reads, Genus, Combo.contaminant)

#Filter by over 250 reads in the full dataset

comp.MD.D2 <- filter(comp.MD.D, Total.reads>250) #largly consistant. No major ASVs (all under 500 reads) noted that are not appropriatly adjusted.

#look at ASVs that are likely to be all contamination - lab controls where both thresholds flag a contaminant

comp.lab <- filter(Decontaination.report.2, Prev.0.1.Lab.controls.contaminant =="TRUE" & Prev.0.5.Lab.controls.contaminant =="TRUE")
comp.lab2 <- select(comp.lab, ASV, Mean.blank, Total.reads, Genus, Prev.0.1.Lab.controls.contaminant, Prev.0.5.Lab.controls.contaminant )
#Only two. Both 0 reads. No indication important contaminants have been missed.

#See how many ASVs are ID in microdecon's mean blank

AVSmeanblank <- filter(Decontaination.report.2, Mean.blank>0) #303 ID as contamants

#rebuild phyloseq with decontaminated OTU table

rownames(deconOTUs) <- deconOTUs$ASV
deconOTUs2 <- deconOTUs[-2]
deconOTUs3 <- deconOTUs2[-1]

#Make into phyloseq.

OTU <- otu_table(deconOTUs3, taxa_are_rows = TRUE) 
TAX2 <- tax_table(ps.TU)
META <- sample_data(ps.TU)
SEQ <- refseq(ps.TU)

#combine above into phyloseq object

ps.TUdecon <- phyloseq(OTU, TAX2, META, SEQ)

#recalculate alpha and beta diversity and relative abundance as per BPS

pAlpha = plot_richness(ps.TUdecon,
                       shape = "Control.type",
                       color = "Location",
                       measures = c("Observed", "Chao1", "Shannon", "InvSimpson"),
                       title = "Alpha Diveristy")
pAlpha + geom_point(size = 5)


#Calculate metrics for scorecard. Review each on average. Observed - actual no. ASVs, hills no. D0, Chao1 - total diversity estimator, Shannon - entropy, exp Shannon is Hills D1 (effective species number if all equally weighted by abundance), inv-Simpson, is Hills D2 effective species number with more weight to more abundant species/ASVs.
library(data.table)

# Store as a new data variable
alphadt = data.table(pAlpha$data)

#subset to just observed
alphadtO <- alphadt[(variable == "Observed")]
# Calc mean observed
meanobserved <- mean(alphadtO$value) #388
# Subset to just the Chao1 index
alphadtC <- alphadt[(variable == "Chao1")]
# Calc mean Chao1
meanChao1 <- mean(alphadtC$value) #426
#subset to just Shannon
alphadtS <- alphadt[(variable == "Shannon")]
# Calc mean Shannon
meanshannon <- mean(alphadtS$value) #3.34
#Calc exp of Shannon (Hill no D1)
expshannon <- exp(meanshannon) #28.18
#subset to just inv simpson
alphadtI <- alphadt[(variable == "InvSimpson")]
library(dplyr)
alphadtI2 <- filter(alphadtI, value!= "Inf")#Raw one gives infinity, there are a couple of samples driving this so they can be pulled out to get a more sensible result.
# Calc mean inv simpson
meaninvsimp <- mean(alphadtI2$value) #18

#Beta diversity (between sample variation) - Bray-curtis
library(vegan)

#create new ps object  without samples with no reads as it effects the bray-curtis matrix

ps.TUdecon.no0s <- prune_samples(sample_sums(ps.TUdecon)>=1, ps.TUdecon) #prune samples without reads from phyloseq object

betadiversity <- vegdist(t(otu_table(ps.TUdecon.no0s)), method = "bray", upper=TRUE, diag=FALSE) #produces matix. 

#calculate desired metrics - from sums of all the distances in the (square) matrix
betadiversitydata <- as.matrix(betadiversity) 

#Remove 0s (from comparison to a site to itself) as they skew measures below
diag(betadiversitydata)=NA #adds NAs to diagonal (all 0 currently)
nrow(betadiversitydata) #66
betadiversitydata<-t(matrix(t(betadiversitydata)[which(!is.na(betadiversitydata))],nrow=66,ncol=65)) #removes NAs from matrix

#Mean of distances
meanbetadiversity <- mean(betadiversitydata) #0.91

#Median of distances
medianbetadiversity <- median(betadiversitydata) #0.94

#range of distances
rangebetadiversity <- range(betadiversitydata) #0.248 - 1

#standard deviation of distances

sdbetadiversity <- sd(betadiversitydata) #0.10

#Abundance - differential abundance in phyloseq and DESeq2.
library(DESeq2)

ps.sub = subset_samples(ps.TUdecon.no0s, Location != "<NA>") #these will be extraction/PCR negatives - fine to take out as would be removed by decontamination anyway
otu_table(ps.sub) <- (otu_table(ps.sub))+1 #Removes 0 which upset DESeq2. As added to all should not affect the differential abundance. No variance stabilisation at this point. Metrics calculated consistantly for everything being compared.
diagdds = phyloseq_to_deseq2(ps.sub, ~ Location)
diagdds2 = DESeq(diagdds, test="Wald", fitType="parametric") 

#results table
res = results(diagdds2, cooksCutoff = FALSE)
alpha = 0.01
sigtab = res[which(res$padj < alpha), ]
sigtab = cbind(as(sigtab, "data.frame"), as(tax_table(ps.sub)[rownames(sigtab), ], "matrix"))
sigtab1 <- as.data.frame(sigtab)
dim(sigtab) #54, 13

#plot of results if desired - no of ASVs sig differntially abundant by location

theme_set(theme_bw())
scale_fill_discrete <- function(palname = "Set1", ...) {
scale_fill_brewer(palette = palname, ...)
}
#Phylum order
x = tapply(sigtab$log2FoldChange, sigtab$Phylum, function(x) max(x))
x = sort(x, TRUE)
sigtab$Phylum = factor(as.character(sigtab$Phylum), levels=names(x))
#Genus order
x = tapply(sigtab$log2FoldChange, sigtab$Genus, function(x) max(x))
x = sort(x, TRUE)
sigtab$Genus = factor(as.character(sigtab$Genus), levels=names(x))
ggplot(sigtab, aes(x=Genus, y=log2FoldChange, color=Phylum)) + geom_point(size=6) + 
theme(axis.text.x = element_text(angle = -90, hjust = 0, vjust=0.5))

#Save decontaminated phyloseq file

save(ps.TUdecon, file = "PSITSParksDecontam2005.Rda")

#Save workspace

save.image("~/Desktop/ParksITS/USEARCH/ParksITSDecontaminationBPSno0s.RData")
