options(echo=TRUE) # Enable output in Rscript for debugging
library("phyloseq")

setwd("~/Desktop/ParksITS/USEARCH") #Change to relevant directory

#Import RDP taxonomy to R
library("RDPutils")
  USEARCHphy.table.RDP <-import_sintax_file("sintax.txt", confidence = 0.8) #change to relevant file

#Import OTU table to R
USEARCHOTU.table <- read.csv("zotutab_raw.csv", header = TRUE, sep=",", row.names = 1) #same error as for 16S, OTU table looks fine in excel

#Make into phyloseq.

OTU = otu_table(USEARCHOTU.table, taxa_are_rows = TRUE) 
TAX = tax_table(USEARCHphy.table)

#combine above into phyloseq object

ps = phyloseq(OTU, USEARCHphy.table)

#bring metadata into R

metadata <- read.csv("~/Documents/PhD sample data/ParksMetadata16S.csv", sep=",", header=TRUE, row.names = 1) #change to relevant file

#bring metadata into phyloseq object

ps <- merge_phyloseq(ps, sample_data(metadata))

# script to bring in ZOTU sequence data into Phyloseq (so it is comparable to Dada2 output)
#load zOTUs fasta into DNA string object and create file called reference seqences
library(Biostrings)
  reference_seqs <- readDNAStringSet(file = "zotusITS.fa",
                                   format = "fasta", nrec = -1L, skip = 0L, seek.first.rec = FALSE, use.names = TRUE) #change to relevant file
rs <- reference_seqs
SEQ <- refseq(rs)

#put into physloeq
SAM <- sample_data(metadata)
ps <- phyloseq(OTU,SEQ,TAX,SAM)

#view refseq and put it into a data frame for easier export/manipulation

refseq(ps)
seqsummary <- as.data.frame(refseq(ps)) #makes data frame with the ASV names and the corresponding sequences 

#code to make this in to an OTU table which looks consistant to Dada2 if desireed, for ease of comparison

#Paste OTU table and seq summary together in R by ASV
library(dplyr)
OTU.table <- as.data.frame(otu_table(ps)) #Make this a data frame too

#Put ZOTUs in the first column so it can be accessed by join commmand below

library(tibble)
OTU.table <- rownames_to_column(OTU.table, "ASV")
seqsummary <- rownames_to_column(seqsummary, "ASV")

#Join files by ASV

OTUwseq <- left_join(seqsummary, OTU.table, by = "ASV")

#delete ASV nos and replace with the DNA seq

row.names(OTUwseq) <- OTUwseq$x

#delete ASV and X cols so it matches the OTU Dada2 outputs

OTUwseq <- OTUwseq[-c(1,2)]

#This can then be exported in to a CSV file or into phyloseq for further work

write.csv(OTUwseq, "OTUwseqFinalUSEARCH16SParks1505.csv", row.name = TRUE) 

#save workspace

save.image("~/Desktop/Parks16S/USEARCH/16SParksUSEARCHintopsfinal141505.RData")